.libPaths("C:/R_packages")
library(rgdal)
library(raster)
library(data.table)
library(ggplot2)
library(SDMTools)
library(spatial)
library(GISTools)
library(dismo)
library(scales)
library(plyr)
library(splines2)
library(splines)

# Multipanel figure function
##########################

multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

##########################

#############################################
# Rice
#############################################

south<-1

if (south==1) {
suitcov<-fread("G:/Ducks_final/SuitabilityByCoverSouth09022020.csv", header=TRUE)
suitcov$date[which(suitcov$date=="2010-11-01to2010-11-15")]<-"1-Nov2010to15Nov2010"
suitcov$date[which(suitcov$date=="2010-1-16to2010-1-31")]<-"16-Jan2010to31Jan2010"
suitcov$date[which(suitcov$date=="2015-2-26to2015-3-06")]<-"20150226to20150306"
suitcov$date[which(suitcov$date=="2014-3-02to2014-3-11")]<-"20140302to20140311"
suitcov$date[which(suitcov$date=="2014-4-19to2014-4-28")]<-"20140419to20140428"
suitcov$date[which(suitcov$date=="2011-9-01to2011-9-15")]<-"1-Sep2011to15Sep2011"
suitcov$date[which(suitcov$date=="2013-11-26to2013-12-05")]<-"20131126to20131205"
suitcov$date[which(suitcov$date=="2016-12-20to2016-12-29")]<-"20161220to20161229"
suitcov$date[which(suitcov$date=="2014-1-13to2014-1-22")]<-"20140113to20140122"
suitcov$date[which(suitcov$date=="2016-2-20to2016-2-29")]<-"20160220to20160229"
suitcov$date[which(suitcov$date=="2016-3-07to2016-3-16")]<-"20160307to20160316"
suitcov$date[which(suitcov$date=="2016-4-01to2016-4-11")]<-"20160401to20160411"
} else {
  suitcov<-fread("G:/Ducks_final/SuitabilityByCoverNorth09022020.csv", header=TRUE)
}
wetcov<-fread("G:/Ducks_final/FloodingSummaries05222020v2.csv", header=TRUE)

ricedryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="South")
ricewetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="South")
riceNsuit<-subset(suitcov, suitcov$type=="rice" & suitcov$NS=="South") # Both models here
riceNsuit$wetcov<-rep(NA, nrow(riceNsuit))
riceNsuit$month<-rep(NA, nrow(riceNsuit))
riceNsuit$wetdry<-rep(NA, nrow(riceNsuit))
for (index in 1:length(ricedryN)) {
  riceNsuit$wetcov[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$rice_ha[index]
  riceNsuit$wetcov[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$rice_ha[index]
  riceNsuit$month[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Month[index]
  riceNsuit$month[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Month[index]
  riceNsuit$wetdry[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Drywet[index]
  riceNsuit$wetdry[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Drywet[index]
}
riceNsuit<-riceNsuit[-which(riceNsuit$model=="Long")]
riceNsuitcov<-subset(riceNsuit, riceNsuit$model=="CoverOnly") 
riceNsuityld<-subset(riceNsuit, riceNsuit$model=="CoverYield") 

ricedryNcov<-subset(riceNsuitcov, riceNsuitcov$wetdry=="Dry")
ricewetNcov<-subset(riceNsuitcov, riceNsuitcov$wetdry=="Wet")

names(ricedryNcov)<-c("V1", "dry_date", "NS", "type", "model", "dry_suit", "dry_cells", "dry_cells_NA", "dry_wetcov", "month", "wetdry")

ricedryNcov$wet_date<-rep(NA, nrow(ricedryNcov))
ricedryNcov$wet_suit<-rep(NA, nrow(ricedryNcov))
ricedryNcov$wet_cells<-rep(NA, nrow(ricedryNcov))
ricedryNcov$wet_cells_NA<-rep(NA, nrow(ricedryNcov))
ricedryNcov$wet_wetcov<-rep(NA, nrow(ricedryNcov))

for (index in c(9, 10, 11, 12, 1, 2, 3, 4)) {
  ricedryNcov$wet_date[which(ricedryNcov$month==index)]<-ricewetNcov$date[which(ricewetNcov$month==index)]
  ricedryNcov$wet_suit[which(ricedryNcov$month==index)]<-ricewetNcov$suit[which(ricewetNcov$month==index)]
  ricedryNcov$wet_cells[which(ricedryNcov$month==index)]<-ricewetNcov$cells[which(ricewetNcov$month==index)]
  ricedryNcov$wet_cells_NA[which(ricedryNcov$month==index)]<-ricewetNcov$cells_NA[which(ricewetNcov$month==index)]
  ricedryNcov$wet_wetcov[which(ricedryNcov$month==index)]<-ricewetNcov$wetcov[which(ricewetNcov$month==index)]
}

ricecov<-ricedryNcov
ricecov$diff_suit<-ricecov$wet_suit-ricecov$dry_suit
ricecov$diff_cov<-(ricecov$wet_wetcov-ricecov$dry_wetcov)/ricecov$wet_wetcov

month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
ricecov$month2<-month2tab[ricecov$month]

p1<-ggplot(data=ricecov, aes(x=diff_cov, y=diff_suit)) + #, color=as.factor(month2)))+
  geom_smooth(method="lm", colour="black", size=0.5) +
  geom_point(size=4, aes(color=as.factor(ricecov$month2)))+
  scale_color_brewer(palette="Spectral") +
  theme_classic() +
  theme(legend.position="none")+
  labs(title="Rice - Flooded Cover Only Models",x="Difference in Flooding: ([ha flooded wet yr] - [ha flooded dry yr])/[ha flooded wet yr]", y = "Difference in Suitability")


ricedryNyld<-subset(riceNsuityld, riceNsuityld$wetdry=="Dry")
ricewetNyld<-subset(riceNsuityld, riceNsuityld$wetdry=="Wet")

names(ricedryNyld)<-c("V1", "dry_date", "NS", "type", "model", "dry_suit", "dry_cells", "dry_cells_NA", "dry_wetcov", "month", "wetdry")

ricedryNyld$wet_date<-rep(NA, nrow(ricedryNyld))
ricedryNyld$wet_suit<-rep(NA, nrow(ricedryNyld))
ricedryNyld$wet_cells<-rep(NA, nrow(ricedryNyld))
ricedryNyld$wet_cells_NA<-rep(NA, nrow(ricedryNyld))
ricedryNyld$wet_wetcov<-rep(NA, nrow(ricedryNyld))

for (index in c(9, 10, 11, 12, 1, 2, 3, 4)) {
  ricedryNyld$wet_date[which(ricedryNyld$month==index)]<-ricewetNyld$date[which(ricewetNyld$month==index)]
  ricedryNyld$wet_suit[which(ricedryNyld$month==index)]<-ricewetNyld$suit[which(ricewetNyld$month==index)]
  ricedryNyld$wet_cells[which(ricedryNyld$month==index)]<-ricewetNyld$cells[which(ricewetNyld$month==index)]
  ricedryNyld$wet_cells_NA[which(ricedryNyld$month==index)]<-ricewetNyld$cells_NA[which(ricewetNyld$month==index)]
  ricedryNyld$wet_wetcov[which(ricedryNyld$month==index)]<-ricewetNyld$wetcov[which(ricewetNyld$month==index)]
}

riceyld<-ricedryNyld
riceyld$diff_suit<-riceyld$wet_suit-riceyld$dry_suit
riceyld$diff_cov<-(riceyld$wet_wetcov-riceyld$dry_wetcov)/riceyld$wet_wetcov

month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
riceyld$month2<-month2tab[riceyld$month]


p4<-ggplot(data=riceyld, aes(x=diff_cov, y=diff_suit))+
  geom_smooth(method="lm", colour="black", size=0.5) +
  geom_point(size=4, aes(color=as.factor(riceyld$month2)))+
  scale_color_brewer(palette="Spectral") +
  #scale_fill_manual(values=c('red', 'orange', 'green', 'darkgreen', 'lightblue', 'darkblue', 'purple', 'pink')) +
    theme_classic() +   theme(legend.position="none")+
  labs(title="Rice - Flooded Cover AND Yield Models",x="Difference in Flooding: ([ha flooded wet yr] - [ha flooded dry yr])/[ha flooded wet yr]", y = "Difference in Suitability")


#############################################
# Wetlands
#############################################


wetlanddryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="South")
wetlandwetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="South")
wetlandNsuit<-subset(suitcov, suitcov$type=="AllWetlands" & suitcov$NS=="South") # Both models here
wetlandNsuit$wetcov<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$month<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$wetdry<-rep(NA, nrow(wetlandNsuit))
for (index in 1:length(wetlanddryN)) {
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$wetland_ha[index]
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$wetland_ha[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Month[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Month[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Drywet[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Drywet[index]
}
wetlandNsuit<-wetlandNsuit[-which(wetlandNsuit$model=="Long")]
wetlandNsuitcov<-subset(wetlandNsuit, wetlandNsuit$model=="CoverOnly") 
wetlandNsuityld<-subset(wetlandNsuit, wetlandNsuit$model=="CoverYield") 

wetlanddryNcov<-subset(wetlandNsuitcov, wetlandNsuitcov$wetdry=="Dry")
wetlandwetNcov<-subset(wetlandNsuitcov, wetlandNsuitcov$wetdry=="Wet")

names(wetlanddryNcov)<-c("V1", "dry_date", "NS", "type", "model", "dry_suit", "dry_cells", "dry_cells_NA", "dry_wetcov", "month", "wetdry")

wetlanddryNcov$wet_date<-rep(NA, nrow(wetlanddryNcov))
wetlanddryNcov$wet_suit<-rep(NA, nrow(wetlanddryNcov))
wetlanddryNcov$wet_cells<-rep(NA, nrow(wetlanddryNcov))
wetlanddryNcov$wet_cells_NA<-rep(NA, nrow(wetlanddryNcov))
wetlanddryNcov$wet_wetcov<-rep(NA, nrow(wetlanddryNcov))

for (index in c(9, 10, 11, 12, 1, 2, 3, 4)) {
  wetlanddryNcov$wet_date[which(wetlanddryNcov$month==index)]<-wetlandwetNcov$date[which(wetlandwetNcov$month==index)]
  wetlanddryNcov$wet_suit[which(wetlanddryNcov$month==index)]<-wetlandwetNcov$suit[which(wetlandwetNcov$month==index)]
  wetlanddryNcov$wet_cells[which(wetlanddryNcov$month==index)]<-wetlandwetNcov$cells[which(wetlandwetNcov$month==index)]
  wetlanddryNcov$wet_cells_NA[which(wetlanddryNcov$month==index)]<-wetlandwetNcov$cells_NA[which(wetlandwetNcov$month==index)]
  wetlanddryNcov$wet_wetcov[which(wetlanddryNcov$month==index)]<-wetlandwetNcov$wetcov[which(wetlandwetNcov$month==index)]
}

wetlandcov<-wetlanddryNcov
wetlandcov$diff_suit<-wetlandcov$wet_suit-wetlandcov$dry_suit
wetlandcov$diff_cov<-(wetlandcov$wet_wetcov-wetlandcov$dry_wetcov)/wetlandcov$wet_wetcov

month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
wetlandcov$month2<-month2tab[wetlandcov$month]


p2<-ggplot(data=wetlandcov, aes(x=diff_cov, y=diff_suit))+
  geom_smooth(method="lm", colour="black", size=0.5) +
  geom_point(size=4, aes(color=as.factor(wetlandcov$month2)))+
  scale_color_brewer(palette="Spectral") +
  #scale_fill_manual(values=c('red', 'orange', 'green', 'darkgreen', 'lightblue', 'darkblue', 'purple', 'pink')) +
    theme_classic() +   theme(legend.position="none")+
  labs(title="Wetlands - Flooded Cover Only Models",x="Difference in Flooding: ([ha flooded wet yr] - [ha flooded dry yr])/[ha flooded wet yr]", y = "Difference in Suitability")


wetlanddryNyld<-subset(wetlandNsuityld, wetlandNsuityld$wetdry=="Dry")
wetlandwetNyld<-subset(wetlandNsuityld, wetlandNsuityld$wetdry=="Wet")

names(wetlanddryNyld)<-c("V1", "dry_date", "NS", "type", "model", "dry_suit", "dry_cells", "dry_cells_NA", "dry_wetcov", "month", "wetdry")

wetlanddryNyld$wet_date<-rep(NA, nrow(wetlanddryNyld))
wetlanddryNyld$wet_suit<-rep(NA, nrow(wetlanddryNyld))
wetlanddryNyld$wet_cells<-rep(NA, nrow(wetlanddryNyld))
wetlanddryNyld$wet_cells_NA<-rep(NA, nrow(wetlanddryNyld))
wetlanddryNyld$wet_wetcov<-rep(NA, nrow(wetlanddryNyld))

for (index in c(9, 10, 11, 12, 1, 2, 3, 4)) {
  wetlanddryNyld$wet_date[which(wetlanddryNyld$month==index)]<-wetlandwetNyld$date[which(wetlandwetNyld$month==index)]
  wetlanddryNyld$wet_suit[which(wetlanddryNyld$month==index)]<-wetlandwetNyld$suit[which(wetlandwetNyld$month==index)]
  wetlanddryNyld$wet_cells[which(wetlanddryNyld$month==index)]<-wetlandwetNyld$cells[which(wetlandwetNyld$month==index)]
  wetlanddryNyld$wet_cells_NA[which(wetlanddryNyld$month==index)]<-wetlandwetNyld$cells_NA[which(wetlandwetNyld$month==index)]
  wetlanddryNyld$wet_wetcov[which(wetlanddryNyld$month==index)]<-wetlandwetNyld$wetcov[which(wetlandwetNyld$month==index)]
}

wetlandyld<-wetlanddryNyld
wetlandyld$diff_suit<-wetlandyld$wet_suit-wetlandyld$dry_suit
wetlandyld$diff_cov<-(wetlandyld$wet_wetcov-wetlandyld$dry_wetcov)/wetlandyld$wet_wetcov

month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
wetlandyld$month2<-month2tab[wetlandyld$month]


p5<-ggplot(data=wetlandyld, aes(x=diff_cov, y=diff_suit))+
  geom_smooth(method="lm", colour="black", size=0.5) +
  geom_point(size=4, aes(color=as.factor(wetlandyld$month2)))+
  scale_color_brewer(palette="Spectral") +
  #scale_fill_manual(values=c('red', 'orange', 'green', 'darkgreen', 'lightblue', 'darkblue', 'purple', 'pink')) +
    theme_classic() +   theme(legend.position="none")+
  labs(title="Wetlands - Flooded Cover AND Yield Models",x="Difference in Flooding: ([ha flooded wet yr] - [ha flooded dry yr])/[ha flooded wet yr]", y = "Difference in Suitability")




#############################################
# Non-rice Crops
#############################################


nonricedryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="South")
nonricewetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="South")
nonriceNsuit<-subset(suitcov, suitcov$type=="NonriceCrop" & suitcov$NS=="South") # Both models here
nonriceNsuit$wetcov<-rep(NA, nrow(nonriceNsuit))
nonriceNsuit$month<-rep(NA, nrow(nonriceNsuit))
nonriceNsuit$wetdry<-rep(NA, nrow(nonriceNsuit))
for (index in 1:length(nonricedryN)) {
  nonriceNsuit$wetcov[which(nonriceNsuit$date==nonricewetN$date[index])]<-nonricewetN$agr_ha[index]
  nonriceNsuit$wetcov[which(nonriceNsuit$date==nonricedryN$date[index])]<-nonricedryN$agr_ha[index]
  nonriceNsuit$month[which(nonriceNsuit$date==nonricewetN$date[index])]<-nonricewetN$Month[index]
  nonriceNsuit$month[which(nonriceNsuit$date==nonricedryN$date[index])]<-nonricedryN$Month[index]
  nonriceNsuit$wetdry[which(nonriceNsuit$date==nonricewetN$date[index])]<-nonricewetN$Drywet[index]
  nonriceNsuit$wetdry[which(nonriceNsuit$date==nonricedryN$date[index])]<-nonricedryN$Drywet[index]
}
nonriceNsuit<-nonriceNsuit[-which(nonriceNsuit$model=="Long")]
nonriceNsuitcov<-subset(nonriceNsuit, nonriceNsuit$model=="CoverOnly") 
nonriceNsuityld<-subset(nonriceNsuit, nonriceNsuit$model=="CoverYield") 

nonricedryNcov<-subset(nonriceNsuitcov, nonriceNsuitcov$wetdry=="Dry")
nonricewetNcov<-subset(nonriceNsuitcov, nonriceNsuitcov$wetdry=="Wet")

names(nonricedryNcov)<-c("V1", "dry_date", "NS", "type", "model", "dry_suit", "dry_cells", "dry_cells_NA", "dry_wetcov", "month", "wetdry")

nonricedryNcov$wet_date<-rep(NA, nrow(nonricedryNcov))
nonricedryNcov$wet_suit<-rep(NA, nrow(nonricedryNcov))
nonricedryNcov$wet_cells<-rep(NA, nrow(nonricedryNcov))
nonricedryNcov$wet_cells_NA<-rep(NA, nrow(nonricedryNcov))
nonricedryNcov$wet_wetcov<-rep(NA, nrow(nonricedryNcov))

for (index in c(9, 10, 11, 12, 1, 2, 3, 4)) {
  nonricedryNcov$wet_date[which(nonricedryNcov$month==index)]<-nonricewetNcov$date[which(nonricewetNcov$month==index)]
  nonricedryNcov$wet_suit[which(nonricedryNcov$month==index)]<-nonricewetNcov$suit[which(nonricewetNcov$month==index)]
  nonricedryNcov$wet_cells[which(nonricedryNcov$month==index)]<-nonricewetNcov$cells[which(nonricewetNcov$month==index)]
  nonricedryNcov$wet_cells_NA[which(nonricedryNcov$month==index)]<-nonricewetNcov$cells_NA[which(nonricewetNcov$month==index)]
  nonricedryNcov$wet_wetcov[which(nonricedryNcov$month==index)]<-nonricewetNcov$wetcov[which(nonricewetNcov$month==index)]
}

nonricecov<-nonricedryNcov
nonricecov$diff_suit<-nonricecov$wet_suit-nonricecov$dry_suit
nonricecov$diff_cov<-(nonricecov$wet_wetcov-nonricecov$dry_wetcov)/nonricecov$wet_wetcov

month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
nonricecov$month2<-month2tab[nonricecov$month]


p3<-ggplot(data=nonricecov, aes(x=diff_cov, y=diff_suit))+
  geom_smooth(method="lm", colour="black", size=0.5) +
  geom_point(size=4, aes(color=as.factor(nonricecov$month2)))+
  scale_color_brewer(palette="Spectral") +    theme_classic() +   theme(legend.position="none")+
  labs(title="Non-rice crops - Flooded Cover Only Models",x="Difference in Flooding: ([ha flooded wet yr] - [ha flooded dry yr])/[ha flooded wet yr]", y = "Difference in Suitability")


nonricedryNyld<-subset(nonriceNsuityld, nonriceNsuityld$wetdry=="Dry")
nonricewetNyld<-subset(nonriceNsuityld, nonriceNsuityld$wetdry=="Wet")

names(nonricedryNyld)<-c("V1", "dry_date", "NS", "type", "model", "dry_suit", "dry_cells", "dry_cells_NA", "dry_wetcov", "month", "wetdry")

nonricedryNyld$wet_date<-rep(NA, nrow(nonricedryNyld))
nonricedryNyld$wet_suit<-rep(NA, nrow(nonricedryNyld))
nonricedryNyld$wet_cells<-rep(NA, nrow(nonricedryNyld))
nonricedryNyld$wet_cells_NA<-rep(NA, nrow(nonricedryNyld))
nonricedryNyld$wet_wetcov<-rep(NA, nrow(nonricedryNyld))

for (index in c(9, 10, 11, 12, 1, 2, 3, 4)) {
  nonricedryNyld$wet_date[which(nonricedryNyld$month==index)]<-nonricewetNyld$date[which(nonricewetNyld$month==index)]
  nonricedryNyld$wet_suit[which(nonricedryNyld$month==index)]<-nonricewetNyld$suit[which(nonricewetNyld$month==index)]
  nonricedryNyld$wet_cells[which(nonricedryNyld$month==index)]<-nonricewetNyld$cells[which(nonricewetNyld$month==index)]
  nonricedryNyld$wet_cells_NA[which(nonricedryNyld$month==index)]<-nonricewetNyld$cells_NA[which(nonricewetNyld$month==index)]
  nonricedryNyld$wet_wetcov[which(nonricedryNyld$month==index)]<-nonricewetNyld$wetcov[which(nonricewetNyld$month==index)]
}

nonriceyld<-nonricedryNyld
nonriceyld$diff_suit<-nonriceyld$wet_suit-nonriceyld$dry_suit
nonriceyld$diff_cov<-(nonriceyld$wet_wetcov-nonriceyld$dry_wetcov)/nonriceyld$wet_wetcov

month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
nonriceyld$month2<-month2tab[nonriceyld$month]


p6<-ggplot(data=nonriceyld, aes(x=diff_cov, y=diff_suit))+
  geom_smooth(method="lm", colour="black", size=0.5) +
  geom_point(size=4, aes(color=as.factor(nonriceyld$month2)))+
  scale_color_brewer(palette="Spectral") +  theme_classic() +   #theme(legend.position="none")+
  labs(title="Non-rice crops - Flooded Cover AND Yield Models",x="Difference in Flooding: ([ha flooded wet yr] - [ha flooded dry yr])/[ha flooded wet yr]", y = "Difference in Suitability")











# Multipanel figure function
##########################

multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

##########################

multiplot(p1, p4, p5, p2, p6, p3, cols=3)
multiplot(p5, p2, p6, p3, cols=2)

