.libPaths("C:/R_packages")
library(rgdal)
library(raster)
library(data.table)
library(ggplot2)
library(SDMTools)
library(spatial)
library(GISTools)
library(dismo)
library(scales)
library(plyr)
library(splines2)
library(splines)

# Multipanel figure function
##########################

multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

##########################

######################################

suitcovNS<-fread("G:/Ducks_final/AreaByCover03292022.csv", header=TRUE)
suitcov<-subset(suitcovNS, suitcovNS$NS=="North")
wetcov<-fread("G:/Ducks_final/FloodingSummaries05222020v2.csv", header=TRUE)

ricedryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="North")
ricewetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="North")
riceNsuit<-subset(suitcov, suitcov$type=="rice" & suitcov$NS=="North") # Both models here
riceNsuit$wetcov<-rep(NA, nrow(riceNsuit))
riceNsuit$month<-rep(NA, nrow(riceNsuit))
riceNsuit$wetdry<-rep(NA, nrow(riceNsuit))
for (index in 1:nrow(ricedryN)) {
riceNsuit$wetcov[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$rice_ha[index]
riceNsuit$wetcov[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$rice_ha[index]
riceNsuit$month[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Month[index]
riceNsuit$month[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Month[index]
riceNsuit$wetdry[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Drywet[index]
riceNsuit$wetdry[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Drywet[index]
}
riceNsuit$wetdry[which(riceNsuit$model=="long")]<-"long"
riceNsuit$month[which(riceNsuit$date=="Sep")]<-9
riceNsuit$month[which(riceNsuit$date=="Oct")]<-10
riceNsuit$month[which(riceNsuit$date=="Nov")]<-11
riceNsuit$month[which(riceNsuit$date=="Dec")]<-12
riceNsuit$month[which(riceNsuit$date=="Jan")]<-1
riceNsuit$month[which(riceNsuit$date=="Feb")]<-2
riceNsuit$month[which(riceNsuit$date=="Mar")]<-3
riceNsuit$month[which(riceNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
riceNsuit$month2<-month2tab[riceNsuit$month]
riceNsuitcov<-subset(riceNsuit, riceNsuit$model=="coveronly") 
riceNsuityld<-subset(riceNsuit, riceNsuit$model=="USGS") 

riceNsuit2<-subset(riceNsuit, riceNsuit$wetdry=="Dry")
riceNsuit2$MonMod<-paste(riceNsuit2$month, "_", riceNsuit2$model, sep="")
names(riceNsuit2)[7]<-"drysuit"
names(riceNsuit2)[8]<-"drywater"
riceNsuit3<-subset(riceNsuit, riceNsuit$wetdry=="Wet")
riceNsuit3$MonMod<-paste(riceNsuit3$month, "_", riceNsuit3$model, sep="")
riceNsuit3<-riceNsuit3[,c("MonMod", "area_suit_ha", "wetcov")]
names(riceNsuit3)<-c("MonMod", "wetarea", "wetwater")
riceNsuit4<-merge(riceNsuit2, riceNsuit3, by.x="MonMod", by.y="MonMod")
riceNsuit4$diffwater<-riceNsuit4$wetwater-riceNsuit4$drywater
riceNsuit4$diffsuit<-riceNsuit4$wetarea-riceNsuit4$drysuit
#plot(riceNsuit4$diffwater, riceNsuit4$diffsuit)

riceNsuit<-riceNsuit[order(riceNsuit$wetdry),]
riceNsuit<-riceNsuit[order(riceNsuit$month2),]

#plot(riceNsuit$wetcov, riceNsuit$suit)

rc<-riceNsuit[grep("coveronly", riceNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-riceNsuit[grep("USGS", riceNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p1<-ggplot(data=riceNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
  #ylim(0,0.06) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="Rice",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','darkgray', 'lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p1



wetlanddryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="North")
wetlandwetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="North")
wetlandNsuit<-subset(suitcov, suitcov$type=="AllWetlands" & suitcov$NS=="North") # Both models here
wetlandNsuit$wetcov<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$month<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$wetdry<-rep(NA, nrow(wetlandNsuit))
for (index in 1:nrow(wetlanddryN)) { ##
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$wetland_ha[index]
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$wetland_ha[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Month[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Month[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Drywet[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Drywet[index]
}
wetlandNsuit$wetdry[which(wetlandNsuit$model=="long")]<-"long"
wetlandNsuit$month[which(wetlandNsuit$date=="Sep")]<-9
wetlandNsuit$month[which(wetlandNsuit$date=="Oct")]<-10
wetlandNsuit$month[which(wetlandNsuit$date=="Nov")]<-11
wetlandNsuit$month[which(wetlandNsuit$date=="Dec")]<-12
wetlandNsuit$month[which(wetlandNsuit$date=="Jan")]<-1
wetlandNsuit$month[which(wetlandNsuit$date=="Feb")]<-2
wetlandNsuit$month[which(wetlandNsuit$date=="Mar")]<-3
wetlandNsuit$month[which(wetlandNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
wetlandNsuit$month2<-month2tab[wetlandNsuit$month]
wetlandNsuitcov<-subset(wetlandNsuit, wetlandNsuit$model=="coveronly") ##
wetlandNsuityld<-subset(wetlandNsuit, wetlandNsuit$model=="USGS") ##

wetlandNsuit2<-subset(wetlandNsuit, wetlandNsuit$wetdry=="Dry")
wetlandNsuit2$MonMod<-paste(wetlandNsuit2$month, "_", wetlandNsuit2$model, sep="")
names(wetlandNsuit2)[7]<-"drysuit" ##
names(wetlandNsuit2)[8]<-"drywater" ##
wetlandNsuit3<-subset(wetlandNsuit, wetlandNsuit$wetdry=="Wet")
wetlandNsuit3$MonMod<-paste(wetlandNsuit3$month, "_", wetlandNsuit3$model, sep="")
wetlandNsuit3<-wetlandNsuit3[,c("MonMod", "area_suit_ha", "wetcov")] ##
names(wetlandNsuit3)<-c("MonMod", "wetarea", "wetwater") ##
wetlandNsuit4<-merge(wetlandNsuit2, wetlandNsuit3, by.x="MonMod", by.y="MonMod")
wetlandNsuit4$diffwater<-wetlandNsuit4$wetwater-wetlandNsuit4$drywater
wetlandNsuit4$diffsuit<-wetlandNsuit4$wetsuit-wetlandNsuit4$drysuit
#plot(wetlandNsuit4$diffwater, wetlandNsuit4$diffsuit)

wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$wetdry),]
wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$month2),]

#plot(wetlandNsuit$wetcov, wetlandNsuit$suit)

rc<-wetlandNsuit[grep("coveronly", wetlandNsuit$model),] ##
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)])) ##
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-wetlandNsuit[grep("USGS", wetlandNsuit$model),] ##
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)])) ##
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p2<-ggplot(data=wetlandNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+ ##
  #ylim(0.2,0.8) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="All Wetlands",x="Month by Water Year (Sept-Apr)", y = "Mean Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','darkgray', 'lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p2


wetlanddryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="North")
wetlandwetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="North")
wetlandNsuit<-subset(suitcov, suitcov$type=="PublicWetlands" & suitcov$NS=="North") # Both models here
wetlandNsuit$wetcov<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$month<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$wetdry<-rep(NA, nrow(wetlandNsuit))
for (index in 1:nrow(wetlanddryN)) {
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$wetland_ha[index]
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$wetland_ha[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Month[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Month[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Drywet[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Drywet[index]
}
wetlandNsuit$wetdry[which(wetlandNsuit$model=="long")]<-"long"
wetlandNsuit$month[which(wetlandNsuit$date=="Sep")]<-9
wetlandNsuit$month[which(wetlandNsuit$date=="Oct")]<-10
wetlandNsuit$month[which(wetlandNsuit$date=="Nov")]<-11
wetlandNsuit$month[which(wetlandNsuit$date=="Dec")]<-12
wetlandNsuit$month[which(wetlandNsuit$date=="Jan")]<-1
wetlandNsuit$month[which(wetlandNsuit$date=="Feb")]<-2
wetlandNsuit$month[which(wetlandNsuit$date=="Mar")]<-3
wetlandNsuit$month[which(wetlandNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
wetlandNsuit$month2<-month2tab[wetlandNsuit$month]
wetlandNsuitcov<-subset(wetlandNsuit, wetlandNsuit$model=="coveronly") 
wetlandNsuityld<-subset(wetlandNsuit, wetlandNsuit$model=="USGS") 

wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$wetdry),]
wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$month2),]

rc<-wetlandNsuit[grep("coveronly", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-wetlandNsuit[grep("USGS", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p3<-ggplot(data=wetlandNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
  #ylim(0.2,0.8) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="Public Wetlands",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','darkgray', 'lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p3


wetlanddryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="North")
wetlandwetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="North")
wetlandNsuit<-subset(suitcov, suitcov$type=="PrivateWetlands" & suitcov$NS=="North") # Both models here
wetlandNsuit$wetcov<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$month<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$wetdry<-rep(NA, nrow(wetlandNsuit))
for (index in 1:nrow(wetlanddryN)) {
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$wetland_ha[index]
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$wetland_ha[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Month[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Month[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Drywet[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Drywet[index]
}
wetlandNsuit$wetdry[which(wetlandNsuit$model=="long")]<-"long"
wetlandNsuit$month[which(wetlandNsuit$date=="Sep")]<-9
wetlandNsuit$month[which(wetlandNsuit$date=="Oct")]<-10
wetlandNsuit$month[which(wetlandNsuit$date=="Nov")]<-11
wetlandNsuit$month[which(wetlandNsuit$date=="Dec")]<-12
wetlandNsuit$month[which(wetlandNsuit$date=="Jan")]<-1
wetlandNsuit$month[which(wetlandNsuit$date=="Feb")]<-2
wetlandNsuit$month[which(wetlandNsuit$date=="Mar")]<-3
wetlandNsuit$month[which(wetlandNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
wetlandNsuit$month2<-month2tab[wetlandNsuit$month]
wetlandNsuitcov<-subset(wetlandNsuit, wetlandNsuit$model=="coveronly") 
wetlandNsuityld<-subset(wetlandNsuit, wetlandNsuit$model=="USGS") 

wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$wetdry),]
wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$month2),]

rc<-wetlandNsuit[grep("coveronly", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-wetlandNsuit[grep("USGS", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p4<-ggplot(data=wetlandNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
 # ylim(0.2,0.8) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="Private Wetlands",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','darkgray', 'lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p4



wetlanddryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="North")
wetlandwetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="North")
wetlandNsuit<-subset(suitcov, suitcov$type=="SeasonalWetlands" & suitcov$NS=="North") # Both models here
wetlandNsuit$wetcov<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$month<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$wetdry<-rep(NA, nrow(wetlandNsuit))
for (index in 1:nrow(wetlanddryN)) {
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$wetland_ha[index]
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$wetland_ha[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Month[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Month[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Drywet[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Drywet[index]
}
wetlandNsuit$wetdry[which(wetlandNsuit$model=="long")]<-"long"
wetlandNsuit$month[which(wetlandNsuit$date=="Sep")]<-9
wetlandNsuit$month[which(wetlandNsuit$date=="Oct")]<-10
wetlandNsuit$month[which(wetlandNsuit$date=="Nov")]<-11
wetlandNsuit$month[which(wetlandNsuit$date=="Dec")]<-12
wetlandNsuit$month[which(wetlandNsuit$date=="Jan")]<-1
wetlandNsuit$month[which(wetlandNsuit$date=="Feb")]<-2
wetlandNsuit$month[which(wetlandNsuit$date=="Mar")]<-3
wetlandNsuit$month[which(wetlandNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
wetlandNsuit$month2<-month2tab[wetlandNsuit$month]
wetlandNsuitcov<-subset(wetlandNsuit, wetlandNsuit$model=="coveronly") 
wetlandNsuityld<-subset(wetlandNsuit, wetlandNsuit$model=="USGS") 

wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$wetdry),]
wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$month2),]

rc<-wetlandNsuit[grep("coveronly", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-wetlandNsuit[grep("USGS", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p5<-ggplot(data=wetlandNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
 # ylim(0.2,0.8) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="Seasonal Wetlands",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','darkgray', 'lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p5


wetlanddryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="North")
wetlandwetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="North")
wetlandNsuit<-subset(suitcov, suitcov$type=="PermanentWetlands" & suitcov$NS=="North") # Both models here
wetlandNsuit$wetcov<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$month<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$wetdry<-rep(NA, nrow(wetlandNsuit))
for (index in 1:nrow(wetlanddryN)) {
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$wetland_ha[index]
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$wetland_ha[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Month[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Month[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Drywet[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Drywet[index]
}
wetlandNsuit$wetdry[which(wetlandNsuit$model=="long")]<-"long"
wetlandNsuit$month[which(wetlandNsuit$date=="Sep")]<-9
wetlandNsuit$month[which(wetlandNsuit$date=="Oct")]<-10
wetlandNsuit$month[which(wetlandNsuit$date=="Nov")]<-11
wetlandNsuit$month[which(wetlandNsuit$date=="Dec")]<-12
wetlandNsuit$month[which(wetlandNsuit$date=="Jan")]<-1
wetlandNsuit$month[which(wetlandNsuit$date=="Feb")]<-2
wetlandNsuit$month[which(wetlandNsuit$date=="Mar")]<-3
wetlandNsuit$month[which(wetlandNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
wetlandNsuit$month2<-month2tab[wetlandNsuit$month]
wetlandNsuitcov<-subset(wetlandNsuit, wetlandNsuit$model=="coveronly") 
wetlandNsuityld<-subset(wetlandNsuit, wetlandNsuit$model=="USGS") 

wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$wetdry),]
wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$month2),]

rc<-wetlandNsuit[grep("coveronly", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-wetlandNsuit[grep("USGS", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p6<-ggplot(data=wetlandNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
 # ylim(0.2,0.8) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="Permanent Wetlands",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','darkgray', 'lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p6



allcropdryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="North")
allcropwetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="North")
allcropNsuit<-subset(suitcov, suitcov$type=="NonriceCrop" & suitcov$NS=="North") # Both models here
allcropNsuit$wetcov<-rep(NA, nrow(allcropNsuit))
allcropNsuit$month<-rep(NA, nrow(allcropNsuit))
allcropNsuit$wetdry<-rep(NA, nrow(allcropNsuit))
for (index in 1:nrow(allcropdryN)) {
  allcropNsuit$wetcov[which(allcropNsuit$date==allcropwetN$date[index])]<-allcropwetN$agr_ha[index]
  allcropNsuit$wetcov[which(allcropNsuit$date==allcropdryN$date[index])]<-allcropdryN$agr_ha[index]
  allcropNsuit$month[which(allcropNsuit$date==allcropwetN$date[index])]<-allcropwetN$Month[index]
  allcropNsuit$month[which(allcropNsuit$date==allcropdryN$date[index])]<-allcropdryN$Month[index]
  allcropNsuit$wetdry[which(allcropNsuit$date==allcropwetN$date[index])]<-allcropwetN$Drywet[index]
  allcropNsuit$wetdry[which(allcropNsuit$date==allcropdryN$date[index])]<-allcropdryN$Drywet[index]
}
allcropNsuit$wetdry[which(allcropNsuit$model=="long")]<-"long"
allcropNsuit$month[which(allcropNsuit$date=="Sep")]<-9
allcropNsuit$month[which(allcropNsuit$date=="Oct")]<-10
allcropNsuit$month[which(allcropNsuit$date=="Nov")]<-11
allcropNsuit$month[which(allcropNsuit$date=="Dec")]<-12
allcropNsuit$month[which(allcropNsuit$date=="Jan")]<-1
allcropNsuit$month[which(allcropNsuit$date=="Feb")]<-2
allcropNsuit$month[which(allcropNsuit$date=="Mar")]<-3
allcropNsuit$month[which(allcropNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
allcropNsuit$month2<-month2tab[allcropNsuit$month]
allcropNsuitcov<-subset(allcropNsuit, allcropNsuit$model=="coveronly") 
allcropNsuityld<-subset(allcropNsuit, allcropNsuit$model=="USGS") 

allcropNsuit2<-subset(allcropNsuit, allcropNsuit$wetdry=="Dry")
allcropNsuit2$MonMod<-paste(allcropNsuit2$month, "_", allcropNsuit2$model, sep="")
names(allcropNsuit2)[6]<-"drysuit"
names(allcropNsuit2)[7]<-"drycells"
names(allcropNsuit2)[9]<-"drywater"
allcropNsuit3<-subset(allcropNsuit, allcropNsuit$wetdry=="Wet")
allcropNsuit3$MonMod<-paste(allcropNsuit3$month, "_", allcropNsuit3$model, sep="")
allcropNsuit3<-allcropNsuit3[,c("MonMod", "suit", "wetcov", "cells")]
names(allcropNsuit3)<-c("MonMod", "wetsuit", "wetwater", "wetcells")
allcropNsuit4<-merge(allcropNsuit2, allcropNsuit3, by.x="MonMod", by.y="MonMod")
allcropNsuit4$diffwater<-allcropNsuit4$wetwater-allcropNsuit4$drywater
allcropNsuit4$diffsuit<-allcropNsuit4$wetsuit-allcropNsuit4$drysuit
#plot(allcropNsuit4$diffwater, allcropNsuit4$diffsuit)

allcropNsuit<-allcropNsuit[order(allcropNsuit$wetdry),]
allcropNsuit<-allcropNsuit[order(allcropNsuit$month2),]

#plot(allcropNsuit$wetcov, allcropNsuit$suit)

rc<-allcropNsuit[grep("coveronly", allcropNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-allcropNsuit[grep("USGS", allcropNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p7<-ggplot(data=allcropNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
  #ylim(0.2,0.8) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  #labs(title="Nonrice Crop",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  labs(title="Nonrice Crop",x=" Sept   Oct   Nov   Dec   Jan   Feb   Mar   Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','darkgray', 'lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p7


multiplot(p2, p7, p1, cols=3)
multiplot(p2, p3, p4, p5, p6, p7, cols=3)



######################################
# Basins
######################################

#suitcov<-fread("G:/Ducks_final/SuitabilityByCoverNorth09022020.csv", header=TRUE)
#wetcov<-fread("G:/Ducks_final/FloodingSummaries05222020v2.csv", header=TRUE)

ricedryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="North")
ricewetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="North")
riceNsuit<-subset(suitcov, suitcov$type=="American" & suitcov$NS=="North") # Both models here
riceNsuit$wetcov<-rep(NA, nrow(riceNsuit))
riceNsuit$month<-rep(NA, nrow(riceNsuit))
riceNsuit$wetdry<-rep(NA, nrow(riceNsuit))
for (index in 1:nrow(ricedryN)) {
  riceNsuit$wetcov[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$rice_ha[index]
  riceNsuit$wetcov[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$rice_ha[index]
  riceNsuit$month[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Month[index]
  riceNsuit$month[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Month[index]
  riceNsuit$wetdry[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Drywet[index]
  riceNsuit$wetdry[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Drywet[index]
}
riceNsuit$wetdry[which(riceNsuit$model=="long")]<-"long"
riceNsuit$month[which(riceNsuit$date=="Sep")]<-9
riceNsuit$month[which(riceNsuit$date=="Oct")]<-10
riceNsuit$month[which(riceNsuit$date=="Nov")]<-11
riceNsuit$month[which(riceNsuit$date=="Dec")]<-12
riceNsuit$month[which(riceNsuit$date=="Jan")]<-1
riceNsuit$month[which(riceNsuit$date=="Feb")]<-2
riceNsuit$month[which(riceNsuit$date=="Mar")]<-3
riceNsuit$month[which(riceNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
riceNsuit$month2<-month2tab[riceNsuit$month]
riceNsuitcov<-subset(riceNsuit, riceNsuit$model=="coveronly") 
riceNsuityld<-subset(riceNsuit, riceNsuit$model=="USGS") 

riceNsuit2<-subset(riceNsuit, riceNsuit$wetdry=="Dry")
riceNsuit2$MonMod<-paste(riceNsuit2$month, "_", riceNsuit2$model, sep="")
names(riceNsuit2)[6]<-"drysuit"
names(riceNsuit2)[7]<-"drycells"
names(riceNsuit2)[9]<-"drywater"
riceNsuit3<-subset(riceNsuit, riceNsuit$wetdry=="Wet")
riceNsuit3$MonMod<-paste(riceNsuit3$month, "_", riceNsuit3$model, sep="")
riceNsuit3<-riceNsuit3[,c("MonMod", "suit", "wetcov", "cells")]
names(riceNsuit3)<-c("MonMod", "wetsuit", "wetwater", "wetcells")
riceNsuit4<-merge(riceNsuit2, riceNsuit3, by.x="MonMod", by.y="MonMod")
riceNsuit4$diffwater<-riceNsuit4$wetwater-riceNsuit4$drywater
riceNsuit4$diffsuit<-riceNsuit4$wetsuit-riceNsuit4$drysuit
#plot(riceNsuit4$diffwater, riceNsuit4$diffsuit)

riceNsuit<-riceNsuit[order(riceNsuit$wetdry),]
riceNsuit<-riceNsuit[order(riceNsuit$month2),]

#plot(riceNsuit$wetcov, riceNsuit$suit)

rc<-riceNsuit[grep("coveronly", riceNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-riceNsuit[grep("USGS", riceNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p1<-ggplot(data=riceNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
  #ylim(0,0.06) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="American",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','darkgray', 'lightgray', 'blue'))  +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p1



ricedryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="North")
ricewetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="North")
riceNsuit<-subset(suitcov, suitcov$type=="Butte" & suitcov$NS=="North") # Both models here
riceNsuit$wetcov<-rep(NA, nrow(riceNsuit))
riceNsuit$month<-rep(NA, nrow(riceNsuit))
riceNsuit$wetdry<-rep(NA, nrow(riceNsuit))
for (index in 1:nrow(ricedryN)) {
  riceNsuit$wetcov[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$rice_ha[index]
  riceNsuit$wetcov[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$rice_ha[index]
  riceNsuit$month[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Month[index]
  riceNsuit$month[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Month[index]
  riceNsuit$wetdry[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Drywet[index]
  riceNsuit$wetdry[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Drywet[index]
}
riceNsuit$wetdry[which(riceNsuit$model=="long")]<-"long"
riceNsuit$month[which(riceNsuit$date=="Sep")]<-9
riceNsuit$month[which(riceNsuit$date=="Oct")]<-10
riceNsuit$month[which(riceNsuit$date=="Nov")]<-11
riceNsuit$month[which(riceNsuit$date=="Dec")]<-12
riceNsuit$month[which(riceNsuit$date=="Jan")]<-1
riceNsuit$month[which(riceNsuit$date=="Feb")]<-2
riceNsuit$month[which(riceNsuit$date=="Mar")]<-3
riceNsuit$month[which(riceNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
riceNsuit$month2<-month2tab[riceNsuit$month]
riceNsuitcov<-subset(riceNsuit, riceNsuit$model=="coveronly") 
riceNsuityld<-subset(riceNsuit, riceNsuit$model=="USGS") 

riceNsuit2<-subset(riceNsuit, riceNsuit$wetdry=="Dry")
riceNsuit2$MonMod<-paste(riceNsuit2$month, "_", riceNsuit2$model, sep="")
names(riceNsuit2)[6]<-"drysuit"
names(riceNsuit2)[7]<-"drycells"
names(riceNsuit2)[9]<-"drywater"
riceNsuit3<-subset(riceNsuit, riceNsuit$wetdry=="Wet")
riceNsuit3$MonMod<-paste(riceNsuit3$month, "_", riceNsuit3$model, sep="")
riceNsuit3<-riceNsuit3[,c("MonMod", "suit", "wetcov", "cells")]
names(riceNsuit3)<-c("MonMod", "wetsuit", "wetwater", "wetcells")
riceNsuit4<-merge(riceNsuit2, riceNsuit3, by.x="MonMod", by.y="MonMod")
riceNsuit4$diffwater<-riceNsuit4$wetwater-riceNsuit4$drywater
riceNsuit4$diffsuit<-riceNsuit4$wetsuit-riceNsuit4$drysuit
#plot(riceNsuit4$diffwater, riceNsuit4$diffsuit)

riceNsuit<-riceNsuit[order(riceNsuit$wetdry),]
riceNsuit<-riceNsuit[order(riceNsuit$month2),]

#plot(riceNsuit$wetcov, riceNsuit$suit)

rc<-riceNsuit[grep("coveronly", riceNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-riceNsuit[grep("USGS", riceNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p2<-ggplot(data=riceNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
  #ylim(0,0.06) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="Butte",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','darkgray', 'lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p2


ricedryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="North")
ricewetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="North")
riceNsuit<-subset(suitcov, suitcov$type=="Colusa" & suitcov$NS=="North") # Both models here
riceNsuit$wetcov<-rep(NA, nrow(riceNsuit))
riceNsuit$month<-rep(NA, nrow(riceNsuit))
riceNsuit$wetdry<-rep(NA, nrow(riceNsuit))
for (index in 1:nrow(ricedryN)) {
  riceNsuit$wetcov[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$rice_ha[index]
  riceNsuit$wetcov[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$rice_ha[index]
  riceNsuit$month[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Month[index]
  riceNsuit$month[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Month[index]
  riceNsuit$wetdry[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Drywet[index]
  riceNsuit$wetdry[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Drywet[index]
}
riceNsuit$wetdry[which(riceNsuit$model=="long")]<-"long"
riceNsuit$month[which(riceNsuit$date=="Sep")]<-9
riceNsuit$month[which(riceNsuit$date=="Oct")]<-10
riceNsuit$month[which(riceNsuit$date=="Nov")]<-11
riceNsuit$month[which(riceNsuit$date=="Dec")]<-12
riceNsuit$month[which(riceNsuit$date=="Jan")]<-1
riceNsuit$month[which(riceNsuit$date=="Feb")]<-2
riceNsuit$month[which(riceNsuit$date=="Mar")]<-3
riceNsuit$month[which(riceNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
riceNsuit$month2<-month2tab[riceNsuit$month]
riceNsuitcov<-subset(riceNsuit, riceNsuit$model=="coveronly") 
riceNsuityld<-subset(riceNsuit, riceNsuit$model=="USGS") 

riceNsuit2<-subset(riceNsuit, riceNsuit$wetdry=="Dry")
riceNsuit2$MonMod<-paste(riceNsuit2$month, "_", riceNsuit2$model, sep="")
names(riceNsuit2)[6]<-"drysuit"
names(riceNsuit2)[7]<-"drycells"
names(riceNsuit2)[9]<-"drywater"
riceNsuit3<-subset(riceNsuit, riceNsuit$wetdry=="Wet")
riceNsuit3$MonMod<-paste(riceNsuit3$month, "_", riceNsuit3$model, sep="")
riceNsuit3<-riceNsuit3[,c("MonMod", "suit", "wetcov", "cells")]
names(riceNsuit3)<-c("MonMod", "wetsuit", "wetwater", "wetcells")
riceNsuit4<-merge(riceNsuit2, riceNsuit3, by.x="MonMod", by.y="MonMod")
riceNsuit4$diffwater<-riceNsuit4$wetwater-riceNsuit4$drywater
riceNsuit4$diffsuit<-riceNsuit4$wetsuit-riceNsuit4$drysuit
#plot(riceNsuit4$diffwater, riceNsuit4$diffsuit)

riceNsuit<-riceNsuit[order(riceNsuit$wetdry),]
riceNsuit<-riceNsuit[order(riceNsuit$month2),]

#plot(riceNsuit$wetcov, riceNsuit$suit)

rc<-riceNsuit[grep("coveronly", riceNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-riceNsuit[grep("USGS", riceNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p3<-ggplot(data=riceNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
  #ylim(0,0.06) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="Colusa",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','darkgray', 'lightgray', 'blue'))  +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p3



ricedryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="North")
ricewetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="North")
riceNsuit<-subset(suitcov, suitcov$type=="Sutter" & suitcov$NS=="North") # Both models here
riceNsuit$wetcov<-rep(NA, nrow(riceNsuit))
riceNsuit$month<-rep(NA, nrow(riceNsuit))
riceNsuit$wetdry<-rep(NA, nrow(riceNsuit))
for (index in 1:nrow(ricedryN)) {
  riceNsuit$wetcov[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$rice_ha[index]
  riceNsuit$wetcov[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$rice_ha[index]
  riceNsuit$month[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Month[index]
  riceNsuit$month[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Month[index]
  riceNsuit$wetdry[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Drywet[index]
  riceNsuit$wetdry[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Drywet[index]
}
riceNsuit$wetdry[which(riceNsuit$model=="long")]<-"long"
riceNsuit$month[which(riceNsuit$date=="Sep")]<-9
riceNsuit$month[which(riceNsuit$date=="Oct")]<-10
riceNsuit$month[which(riceNsuit$date=="Nov")]<-11
riceNsuit$month[which(riceNsuit$date=="Dec")]<-12
riceNsuit$month[which(riceNsuit$date=="Jan")]<-1
riceNsuit$month[which(riceNsuit$date=="Feb")]<-2
riceNsuit$month[which(riceNsuit$date=="Mar")]<-3
riceNsuit$month[which(riceNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
riceNsuit$month2<-month2tab[riceNsuit$month]
riceNsuitcov<-subset(riceNsuit, riceNsuit$model=="coveronly") 
riceNsuityld<-subset(riceNsuit, riceNsuit$model=="USGS") 

riceNsuit2<-subset(riceNsuit, riceNsuit$wetdry=="Dry")
riceNsuit2$MonMod<-paste(riceNsuit2$month, "_", riceNsuit2$model, sep="")
names(riceNsuit2)[6]<-"drysuit"
names(riceNsuit2)[7]<-"drycells"
names(riceNsuit2)[9]<-"drywater"
riceNsuit3<-subset(riceNsuit, riceNsuit$wetdry=="Wet")
riceNsuit3$MonMod<-paste(riceNsuit3$month, "_", riceNsuit3$model, sep="")
riceNsuit3<-riceNsuit3[,c("MonMod", "suit", "wetcov", "cells")]
names(riceNsuit3)<-c("MonMod", "wetsuit", "wetwater", "wetcells")
riceNsuit4<-merge(riceNsuit2, riceNsuit3, by.x="MonMod", by.y="MonMod")
riceNsuit4$diffwater<-riceNsuit4$wetwater-riceNsuit4$drywater
riceNsuit4$diffsuit<-riceNsuit4$wetsuit-riceNsuit4$drysuit
#plot(riceNsuit4$diffwater, riceNsuit4$diffsuit)

riceNsuit<-riceNsuit[order(riceNsuit$wetdry),]
riceNsuit<-riceNsuit[order(riceNsuit$month2),]

#plot(riceNsuit$wetcov, riceNsuit$suit)

rc<-riceNsuit[grep("coveronly", riceNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-riceNsuit[grep("USGS", riceNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p4<-ggplot(data=riceNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
  #ylim(0,0.06) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="Sutter",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','darkgray', 'lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p4



ricedryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="North")
ricewetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="North")
riceNsuit<-subset(suitcov, suitcov$type=="Yolo" & suitcov$NS=="North") # Both models here
riceNsuit$wetcov<-rep(NA, nrow(riceNsuit))
riceNsuit$month<-rep(NA, nrow(riceNsuit))
riceNsuit$wetdry<-rep(NA, nrow(riceNsuit))
for (index in 1:nrow(ricedryN)) {
  riceNsuit$wetcov[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$rice_ha[index]
  riceNsuit$wetcov[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$rice_ha[index]
  riceNsuit$month[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Month[index]
  riceNsuit$month[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Month[index]
  riceNsuit$wetdry[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Drywet[index]
  riceNsuit$wetdry[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Drywet[index]
}
riceNsuit$wetdry[which(riceNsuit$model=="long")]<-"long"
riceNsuit$month[which(riceNsuit$date=="Sep")]<-9
riceNsuit$month[which(riceNsuit$date=="Oct")]<-10
riceNsuit$month[which(riceNsuit$date=="Nov")]<-11
riceNsuit$month[which(riceNsuit$date=="Dec")]<-12
riceNsuit$month[which(riceNsuit$date=="Jan")]<-1
riceNsuit$month[which(riceNsuit$date=="Feb")]<-2
riceNsuit$month[which(riceNsuit$date=="Mar")]<-3
riceNsuit$month[which(riceNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
riceNsuit$month2<-month2tab[riceNsuit$month]
riceNsuitcov<-subset(riceNsuit, riceNsuit$model=="coveronly") 
riceNsuityld<-subset(riceNsuit, riceNsuit$model=="USGS") 

riceNsuit2<-subset(riceNsuit, riceNsuit$wetdry=="Dry")
riceNsuit2$MonMod<-paste(riceNsuit2$month, "_", riceNsuit2$model, sep="")
names(riceNsuit2)[6]<-"drysuit"
names(riceNsuit2)[7]<-"drycells"
names(riceNsuit2)[9]<-"drywater"
riceNsuit3<-subset(riceNsuit, riceNsuit$wetdry=="Wet")
riceNsuit3$MonMod<-paste(riceNsuit3$month, "_", riceNsuit3$model, sep="")
riceNsuit3<-riceNsuit3[,c("MonMod", "suit", "wetcov", "cells")]
names(riceNsuit3)<-c("MonMod", "wetsuit", "wetwater", "wetcells")
riceNsuit4<-merge(riceNsuit2, riceNsuit3, by.x="MonMod", by.y="MonMod")
riceNsuit4$diffwater<-riceNsuit4$wetwater-riceNsuit4$drywater
riceNsuit4$diffsuit<-riceNsuit4$wetsuit-riceNsuit4$drysuit
#plot(riceNsuit4$diffwater, riceNsuit4$diffsuit)

riceNsuit<-riceNsuit[order(riceNsuit$wetdry),]
riceNsuit<-riceNsuit[order(riceNsuit$month2),]

#plot(riceNsuit$wetcov, riceNsuit$suit)

rc<-riceNsuit[grep("coveronly", riceNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-riceNsuit[grep("USGS", riceNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p5<-ggplot(data=riceNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
  #ylim(0,0.06) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="Yolo",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','darkgray', 'lightgray', 'blue')) + 
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p5


################################################
# San Joaguin requires loading South data
################################################

#suitcov<-fread("G:/Ducks_final/SuitabilityByCoverSouth09022020.csv", header=TRUE)
#wetcov<-fread("G:/Ducks_final/FloodingSummaries05222020v2.csv", header=TRUE)

suitcov$date[which(suitcov$date=="2010-11-01to2010-11-15")]<-"1-Nov2010to15Nov2010"
suitcov$date[which(suitcov$date=="2010-1-16to2010-1-31")]<-"16-Jan2010to31Jan2010"
suitcov$date[which(suitcov$date=="2015-2-26to2015-3-06")]<-"20150226to20150306"
suitcov$date[which(suitcov$date=="2014-3-02to2014-3-11")]<-"20140302to20140311"
suitcov$date[which(suitcov$date=="2014-4-19to2014-4-28")]<-"20140419to20140428"
suitcov$date[which(suitcov$date=="2011-9-01to2011-9-15")]<-"1-Sep2011to15Sep2011"
suitcov$date[which(suitcov$date=="2013-11-26to2013-12-05")]<-"20131126to20131205"
suitcov$date[which(suitcov$date=="2016-12-20to2016-12-29")]<-"20161220to20161229"
suitcov$date[which(suitcov$date=="2014-1-13to2014-1-22")]<-"20140113to20140122"
suitcov$date[which(suitcov$date=="2016-2-20to2016-2-29")]<-"20160220to20160229"
suitcov$date[which(suitcov$date=="2016-3-07to2016-3-16")]<-"20160307to20160316"
suitcov$date[which(suitcov$date=="2016-4-01to2016-4-11")]<-"20160401to20160411"

ricedryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="South")
ricewetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="South")
riceNsuit<-subset(suitcov, suitcov$type=="San Joaquin" & suitcov$NS=="South") # Both models here
riceNsuit$wetcov<-rep(NA, nrow(riceNsuit))
riceNsuit$month<-rep(NA, nrow(riceNsuit))
riceNsuit$wetdry<-rep(NA, nrow(riceNsuit))
for (index in 1:nrow(ricedryN)) {
  riceNsuit$wetcov[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$rice_ha[index]
  riceNsuit$wetcov[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$rice_ha[index]
  riceNsuit$month[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Month[index]
  riceNsuit$month[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Month[index]
  riceNsuit$wetdry[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Drywet[index]
  riceNsuit$wetdry[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Drywet[index]
}
riceNsuit$wetdry[which(riceNsuit$model=="Long")]<-"long"
riceNsuit$month[which(riceNsuit$date=="Sep")]<-9
riceNsuit$month[which(riceNsuit$date=="Oct")]<-10
riceNsuit$month[which(riceNsuit$date=="Nov")]<-11
riceNsuit$month[which(riceNsuit$date=="Dec")]<-12
riceNsuit$month[which(riceNsuit$date=="Jan")]<-1
riceNsuit$month[which(riceNsuit$date=="Feb")]<-2
riceNsuit$month[which(riceNsuit$date=="Mar")]<-3
riceNsuit$month[which(riceNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
riceNsuit$month2<-month2tab[riceNsuit$month]
riceNsuitcov<-subset(riceNsuit, riceNsuit$model=="coveronly") 
riceNsuityld<-subset(riceNsuit, riceNsuit$model=="USGS") 

riceNsuit2<-subset(riceNsuit, riceNsuit$wetdry=="Dry")
riceNsuit2$MonMod<-paste(riceNsuit2$month, "_", riceNsuit2$model, sep="")
names(riceNsuit2)[7]<-"drysuit"
names(riceNsuit2)[8]<-"drywater"
riceNsuit3<-subset(riceNsuit, riceNsuit$wetdry=="Wet")
riceNsuit3$MonMod<-paste(riceNsuit3$month, "_", riceNsuit3$model, sep="")
riceNsuit3<-riceNsuit3[,c("MonMod", "area_suit_ha", "wetcov")]
names(riceNsuit3)<-c("MonMod", "wetarea", "wetwater")
riceNsuit4<-merge(riceNsuit2, riceNsuit3, by.x="MonMod", by.y="MonMod")
riceNsuit4$diffwater<-riceNsuit4$wetwater-riceNsuit4$drywater
riceNsuit4$diffsuit<-riceNsuit4$wetsuit-riceNsuit4$drysuit
#plot(riceNsuit4$diffwater, riceNsuit4$diffsuit)

riceNsuit<-riceNsuit[order(riceNsuit$wetdry),]
riceNsuit<-riceNsuit[order(riceNsuit$month2),]

#plot(riceNsuit$wetcov, riceNsuit$suit)

rc<-riceNsuit[grep("coveronly", riceNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-riceNsuit[grep("USGS", riceNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p6<-ggplot(data=riceNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
  #ylim(0,0.06) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="San Joaquin",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red', 'lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p6

ggplot(data=riceNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
  #ylim(0,0.06) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="SAN JOAQUIN BASIN      NORTH VALLEY   ",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','darkgray', 'lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)


multiplot(p1, p4, p2, p5, p3, p6, cols=3)

#########################################
# SOUTH
#########################################

suitcovNS<-fread("G:/Ducks_final/AreaByCover03292022.csv", header=TRUE)
suitcov<-subset(suitcovNS, suitcovNS$NS=="South")
wetcov<-fread("G:/Ducks_final/FloodingSummaries05222020v2.csv", header=TRUE)

suitcov$date[which(suitcov$date=="2010-11-01to2010-11-15")]<-"1-Nov2010to15Nov2010"
suitcov$date[which(suitcov$date=="2010-1-16to2010-1-31")]<-"16-Jan2010to31Jan2010"
suitcov$date[which(suitcov$date=="2015-2-26to2015-3-06")]<-"20150226to20150306"
suitcov$date[which(suitcov$date=="2014-3-02to2014-3-11")]<-"20140302to20140311"
suitcov$date[which(suitcov$date=="2014-4-19to2014-4-28")]<-"20140419to20140428"
suitcov$date[which(suitcov$date=="2011-9-01to2011-9-15")]<-"1-Sep2011to15Sep2011"
suitcov$date[which(suitcov$date=="2013-11-26to2013-12-05")]<-"20131126to20131205"
suitcov$date[which(suitcov$date=="2016-12-20to2016-12-29")]<-"20161220to20161229"
suitcov$date[which(suitcov$date=="2014-1-13to2014-1-22")]<-"20140113to20140122"
suitcov$date[which(suitcov$date=="2016-2-20to2016-2-29")]<-"20160220to20160229"
suitcov$date[which(suitcov$date=="2016-3-07to2016-3-16")]<-"20160307to20160316"
suitcov$date[which(suitcov$date=="2016-4-01to2016-4-11")]<-"20160401to20160411"

ricedryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="South")
ricewetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="South")
riceNsuit<-subset(suitcov, suitcov$type=="rice" & suitcov$NS=="South") # Both models here
riceNsuit$wetcov<-rep(NA, nrow(riceNsuit))
riceNsuit$month<-rep(NA, nrow(riceNsuit))
riceNsuit$wetdry<-rep(NA, nrow(riceNsuit))
for (index in 1:nrow(ricedryN)) {
  riceNsuit$wetcov[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$rice_ha[index]
  riceNsuit$wetcov[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$rice_ha[index]
  riceNsuit$month[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Month[index]
  riceNsuit$month[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Month[index]
  riceNsuit$wetdry[which(riceNsuit$date==ricewetN$date[index])]<-ricewetN$Drywet[index]
  riceNsuit$wetdry[which(riceNsuit$date==ricedryN$date[index])]<-ricedryN$Drywet[index]
}
riceNsuit$wetdry[which(riceNsuit$model=="Long")]<-"long"
riceNsuit$month[which(riceNsuit$date=="Sep")]<-9
riceNsuit$month[which(riceNsuit$date=="Oct")]<-10
riceNsuit$month[which(riceNsuit$date=="Nov")]<-11
riceNsuit$month[which(riceNsuit$date=="Dec")]<-12
riceNsuit$month[which(riceNsuit$date=="Jan")]<-1
riceNsuit$month[which(riceNsuit$date=="Feb")]<-2
riceNsuit$month[which(riceNsuit$date=="Mar")]<-3
riceNsuit$month[which(riceNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
riceNsuit$month2<-month2tab[riceNsuit$month]
riceNsuitcov<-subset(riceNsuit, riceNsuit$model=="coveronly") 
riceNsuityld<-subset(riceNsuit, riceNsuit$model=="USGS") 

riceNsuit2<-subset(riceNsuit, riceNsuit$wetdry=="Dry")
riceNsuit2$MonMod<-paste(riceNsuit2$month, "_", riceNsuit2$model, sep="")
names(riceNsuit2)[7]<-"drysuit"
names(riceNsuit2)[8]<-"drywater"
riceNsuit3<-subset(riceNsuit, riceNsuit$wetdry=="Wet")
riceNsuit3$MonMod<-paste(riceNsuit3$month, "_", riceNsuit3$model, sep="")
riceNsuit3<-riceNsuit3[,c("MonMod", "area_suit_ha", "wetcov")]
names(riceNsuit3)<-c("MonMod", "wetarea", "wetwater")
riceNsuit4<-merge(riceNsuit2, riceNsuit3, by.x="MonMod", by.y="MonMod")
riceNsuit4$diffwater<-riceNsuit4$wetwater-riceNsuit4$drywater
riceNsuit4$diffsuit<-riceNsuit4$wetsuit-riceNsuit4$drysuit
#plot(riceNsuit4$diffwater, riceNsuit4$diffsuit)

riceNsuit<-riceNsuit[order(riceNsuit$wetdry),]
riceNsuit<-riceNsuit[order(riceNsuit$month2),]

#plot(riceNsuit$wetcov, riceNsuit$suit)

rc<-riceNsuit[grep("coveronly", riceNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-riceNsuit[grep("USGS", riceNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p1<-ggplot(data=riceNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
  #ylim(0,0.06) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="Rice",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p1


wetlanddryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="South")
wetlandwetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="South")
wetlandNsuit<-subset(suitcov, suitcov$type=="AllWetlands" & suitcov$NS=="South") # Both models here
wetlandNsuit$wetcov<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$month<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$wetdry<-rep(NA, nrow(wetlandNsuit))
for (index in 1:nrow(wetlanddryN)) {
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$wetland_ha[index]
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$wetland_ha[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Month[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Month[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Drywet[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Drywet[index]
}
wetlandNsuit$wetdry[which(wetlandNsuit$model=="Long")]<-"long"
wetlandNsuit$month[which(wetlandNsuit$date=="Sep")]<-9
wetlandNsuit$month[which(wetlandNsuit$date=="Oct")]<-10
wetlandNsuit$month[which(wetlandNsuit$date=="Nov")]<-11
wetlandNsuit$month[which(wetlandNsuit$date=="Dec")]<-12
wetlandNsuit$month[which(wetlandNsuit$date=="Jan")]<-1
wetlandNsuit$month[which(wetlandNsuit$date=="Feb")]<-2
wetlandNsuit$month[which(wetlandNsuit$date=="Mar")]<-3
wetlandNsuit$month[which(wetlandNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
wetlandNsuit$month2<-month2tab[wetlandNsuit$month]
wetlandNsuitcov<-subset(wetlandNsuit, wetlandNsuit$model=="coveronly") 
wetlandNsuityld<-subset(wetlandNsuit, wetlandNsuit$model=="USGS") 

wetlandNsuit2<-subset(wetlandNsuit, wetlandNsuit$wetdry=="Dry")
wetlandNsuit2$MonMod<-paste(wetlandNsuit2$month, "_", wetlandNsuit2$model, sep="")
names(wetlandNsuit2)[7]<-"drysuit"
names(wetlandNsuit2)[8]<-"drywater"
wetlandNsuit3<-subset(wetlandNsuit, wetlandNsuit$wetdry=="Wet")
wetlandNsuit3$MonMod<-paste(wetlandNsuit3$month, "_", wetlandNsuit3$model, sep="")
wetlandNsuit3<-wetlandNsuit3[,c("MonMod", "area_suit_ha", "wetcov")]
names(wetlandNsuit3)<-c("MonMod", "wetarea", "wetwater")
wetlandNsuit4<-merge(wetlandNsuit2, wetlandNsuit3, by.x="MonMod", by.y="MonMod")
wetlandNsuit4$diffwater<-wetlandNsuit4$wetwater-wetlandNsuit4$drywater
wetlandNsuit4$diffsuit<-wetlandNsuit4$wetsuit-wetlandNsuit4$drysuit
#plot(wetlandNsuit4$diffwater, wetlandNsuit4$diffsuit)

wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$wetdry),]
wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$month2),]

#plot(wetlandNsuit$wetcov, wetlandNsuit$suit)

rc<-wetlandNsuit[grep("coveronly", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-wetlandNsuit[grep("USGS", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p2<-ggplot(data=wetlandNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
  #ylim(0.2,0.8) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="All Wetlands",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p2


wetlanddryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="South")
wetlandwetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="South")
wetlandNsuit<-subset(suitcov, suitcov$type=="PublicWetlands" & suitcov$NS=="South") # Both models here
wetlandNsuit$wetcov<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$month<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$wetdry<-rep(NA, nrow(wetlandNsuit))
for (index in 1:nrow(wetlanddryN)) {
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$wetland_ha[index]
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$wetland_ha[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Month[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Month[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Drywet[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Drywet[index]
}
wetlandNsuit$wetdry[which(wetlandNsuit$model=="Long")]<-"long"
wetlandNsuit$month[which(wetlandNsuit$date=="Sep")]<-9
wetlandNsuit$month[which(wetlandNsuit$date=="Oct")]<-10
wetlandNsuit$month[which(wetlandNsuit$date=="Nov")]<-11
wetlandNsuit$month[which(wetlandNsuit$date=="Dec")]<-12
wetlandNsuit$month[which(wetlandNsuit$date=="Jan")]<-1
wetlandNsuit$month[which(wetlandNsuit$date=="Feb")]<-2
wetlandNsuit$month[which(wetlandNsuit$date=="Mar")]<-3
wetlandNsuit$month[which(wetlandNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
wetlandNsuit$month2<-month2tab[wetlandNsuit$month]
wetlandNsuitcov<-subset(wetlandNsuit, wetlandNsuit$model=="coveronly") 
wetlandNsuityld<-subset(wetlandNsuit, wetlandNsuit$model=="USGS") 

wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$wetdry),]
wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$month2),]

rc<-wetlandNsuit[grep("coveronly", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-wetlandNsuit[grep("USGS", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p3<-ggplot(data=wetlandNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
  #ylim(0.2,0.8) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="Public Wetlands",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red', 'lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p3



wetlanddryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="South")
wetlandwetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="South")
wetlandNsuit<-subset(suitcov, suitcov$type=="PrivateWetlands" & suitcov$NS=="South") # Both models here
wetlandNsuit$wetcov<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$month<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$wetdry<-rep(NA, nrow(wetlandNsuit))
for (index in 1:nrow(wetlanddryN)) {
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$wetland_ha[index]
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$wetland_ha[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Month[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Month[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Drywet[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Drywet[index]
}
wetlandNsuit$wetdry[which(wetlandNsuit$model=="Long")]<-"long"
wetlandNsuit$month[which(wetlandNsuit$date=="Sep")]<-9
wetlandNsuit$month[which(wetlandNsuit$date=="Oct")]<-10
wetlandNsuit$month[which(wetlandNsuit$date=="Nov")]<-11
wetlandNsuit$month[which(wetlandNsuit$date=="Dec")]<-12
wetlandNsuit$month[which(wetlandNsuit$date=="Jan")]<-1
wetlandNsuit$month[which(wetlandNsuit$date=="Feb")]<-2
wetlandNsuit$month[which(wetlandNsuit$date=="Mar")]<-3
wetlandNsuit$month[which(wetlandNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
wetlandNsuit$month2<-month2tab[wetlandNsuit$month]
wetlandNsuitcov<-subset(wetlandNsuit, wetlandNsuit$model=="coveronly") 
wetlandNsuityld<-subset(wetlandNsuit, wetlandNsuit$model=="USGS") 

wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$wetdry),]
wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$month2),]

rc<-wetlandNsuit[grep("coveronly", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-wetlandNsuit[grep("USGS", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p4<-ggplot(data=wetlandNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
  #ylim(0.2,0.8) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="Private Wetlands",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p4



wetlanddryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="South")
wetlandwetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="South")
wetlandNsuit<-subset(suitcov, suitcov$type=="SeasonalWetlands" & suitcov$NS=="South") # Both models here
wetlandNsuit$wetcov<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$month<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$wetdry<-rep(NA, nrow(wetlandNsuit))
for (index in 1:nrow(wetlanddryN)) {
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$wetland_ha[index]
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$wetland_ha[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Month[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Month[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Drywet[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Drywet[index]
}
wetlandNsuit$wetdry[which(wetlandNsuit$model=="Long")]<-"long"
wetlandNsuit$month[which(wetlandNsuit$date=="Sep")]<-9
wetlandNsuit$month[which(wetlandNsuit$date=="Oct")]<-10
wetlandNsuit$month[which(wetlandNsuit$date=="Nov")]<-11
wetlandNsuit$month[which(wetlandNsuit$date=="Dec")]<-12
wetlandNsuit$month[which(wetlandNsuit$date=="Jan")]<-1
wetlandNsuit$month[which(wetlandNsuit$date=="Feb")]<-2
wetlandNsuit$month[which(wetlandNsuit$date=="Mar")]<-3
wetlandNsuit$month[which(wetlandNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
wetlandNsuit$month2<-month2tab[wetlandNsuit$month]
wetlandNsuitcov<-subset(wetlandNsuit, wetlandNsuit$model=="coveronly") 
wetlandNsuityld<-subset(wetlandNsuit, wetlandNsuit$model=="USGS") 

wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$wetdry),]
wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$month2),]

rc<-wetlandNsuit[grep("coveronly", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-wetlandNsuit[grep("USGS", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p5<-ggplot(data=wetlandNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
  #ylim(0.2,0.8) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="Seasonal Wetlands",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p5



wetlanddryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="South")
wetlandwetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="South")
wetlandNsuit<-subset(suitcov, suitcov$type=="PermanentWetlands" & suitcov$NS=="South") # Both models here
wetlandNsuit$wetcov<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$month<-rep(NA, nrow(wetlandNsuit))
wetlandNsuit$wetdry<-rep(NA, nrow(wetlandNsuit))
for (index in 1:nrow(wetlanddryN)) {
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$wetland_ha[index]
  wetlandNsuit$wetcov[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$wetland_ha[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Month[index]
  wetlandNsuit$month[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Month[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlandwetN$date[index])]<-wetlandwetN$Drywet[index]
  wetlandNsuit$wetdry[which(wetlandNsuit$date==wetlanddryN$date[index])]<-wetlanddryN$Drywet[index]
}
wetlandNsuit$wetdry[which(wetlandNsuit$model=="Long")]<-"long"
wetlandNsuit$month[which(wetlandNsuit$date=="Sep")]<-9
wetlandNsuit$month[which(wetlandNsuit$date=="Oct")]<-10
wetlandNsuit$month[which(wetlandNsuit$date=="Nov")]<-11
wetlandNsuit$month[which(wetlandNsuit$date=="Dec")]<-12
wetlandNsuit$month[which(wetlandNsuit$date=="Jan")]<-1
wetlandNsuit$month[which(wetlandNsuit$date=="Feb")]<-2
wetlandNsuit$month[which(wetlandNsuit$date=="Mar")]<-3
wetlandNsuit$month[which(wetlandNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
wetlandNsuit$month2<-month2tab[wetlandNsuit$month]
wetlandNsuitcov<-subset(wetlandNsuit, wetlandNsuit$model=="coveronly") 
wetlandNsuityld<-subset(wetlandNsuit, wetlandNsuit$model=="USGS") 

wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$wetdry),]
wetlandNsuit<-wetlandNsuit[order(wetlandNsuit$month2),]

rc<-wetlandNsuit[grep("coveronly", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-wetlandNsuit[grep("USGS", wetlandNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p6<-ggplot(data=wetlandNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
  #ylim(0.2,0.8) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  labs(title="Permanent Wetlands",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red','lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p6



allcropdryN<-subset(wetcov, wetcov$Drywet=="Dry" & wetcov$NS=="South")
allcropwetN<-subset(wetcov, wetcov$Drywet=="Wet" & wetcov$NS=="South")
allcropNsuit<-subset(suitcov, suitcov$type=="NonriceCrop" & suitcov$NS=="South") # Both models here
allcropNsuit$wetcov<-rep(NA, nrow(allcropNsuit))
allcropNsuit$month<-rep(NA, nrow(allcropNsuit))
allcropNsuit$wetdry<-rep(NA, nrow(allcropNsuit))
for (index in 1:nrow(allcropdryN)) {
  allcropNsuit$wetcov[which(allcropNsuit$date==allcropwetN$date[index])]<-allcropwetN$agr_ha[index]
  allcropNsuit$wetcov[which(allcropNsuit$date==allcropdryN$date[index])]<-allcropdryN$agr_ha[index]
  allcropNsuit$month[which(allcropNsuit$date==allcropwetN$date[index])]<-allcropwetN$Month[index]
  allcropNsuit$month[which(allcropNsuit$date==allcropdryN$date[index])]<-allcropdryN$Month[index]
  allcropNsuit$wetdry[which(allcropNsuit$date==allcropwetN$date[index])]<-allcropwetN$Drywet[index]
  allcropNsuit$wetdry[which(allcropNsuit$date==allcropdryN$date[index])]<-allcropdryN$Drywet[index]
}
allcropNsuit$wetdry[which(allcropNsuit$model=="Long")]<-"long"
allcropNsuit$month[which(allcropNsuit$date=="Sep")]<-9
allcropNsuit$month[which(allcropNsuit$date=="Oct")]<-10
allcropNsuit$month[which(allcropNsuit$date=="Nov")]<-11
allcropNsuit$month[which(allcropNsuit$date=="Dec")]<-12
allcropNsuit$month[which(allcropNsuit$date=="Jan")]<-1
allcropNsuit$month[which(allcropNsuit$date=="Feb")]<-2
allcropNsuit$month[which(allcropNsuit$date=="Mar")]<-3
allcropNsuit$month[which(allcropNsuit$date=="Apr")]<-4
month2tab<-c(5, 6, 7, 8, NA, NA, NA, NA, 1, 2, 3, 4)
allcropNsuit$month2<-month2tab[allcropNsuit$month]
allcropNsuitcov<-subset(allcropNsuit, allcropNsuit$model=="coveronly") 
allcropNsuityld<-subset(allcropNsuit, allcropNsuit$model=="USGS") 

allcropNsuit2<-subset(allcropNsuit, allcropNsuit$wetdry=="Dry")
allcropNsuit2$MonMod<-paste(allcropNsuit2$month, "_", allcropNsuit2$model, sep="")
names(allcropNsuit2)[7]<-"drysuit"
names(allcropNsuit2)[8]<-"drywater"
allcropNsuit3<-subset(allcropNsuit, allcropNsuit$wetdry=="Wet")
allcropNsuit3$MonMod<-paste(allcropNsuit3$month, "_", allcropNsuit3$model, sep="")
allcropNsuit3<-allcropNsuit3[,c("MonMod", "area_suit_ha", "wetcov")]
names(allcropNsuit3)<-c("MonMod", "wetarea", "wetwater")
allcropNsuit4<-merge(allcropNsuit2, allcropNsuit3, by.x="MonMod", by.y="MonMod")
allcropNsuit4$diffwater<-allcropNsuit4$wetwater-allcropNsuit4$drywater
allcropNsuit4$diffsuit<-allcropNsuit4$wetsuit-allcropNsuit4$drysuit
#plot(allcropNsuit4$diffwater, allcropNsuit4$diffsuit)

allcropNsuit<-allcropNsuit[order(allcropNsuit$wetdry),]
allcropNsuit<-allcropNsuit[order(allcropNsuit$month2),]

#plot(allcropNsuit$wetcov, allcropNsuit$suit)

rc<-allcropNsuit[grep("coveronly", allcropNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
polc<-polygonrc

rc<-allcropNsuit[grep("USGS", allcropNsuit$model),]
polygonrc<-as.data.frame(c(rc$area_suit_ha[seq(2,16,2)], rc$area_suit_ha[seq(15,1,-2)]))
names(polygonrc)[1]<-"y"
polygonrc$x<-c(rc$month2[seq(2,16,2)], rc$month2[seq(15,1,-2)])
polygonrc$wetdry<-rep("NA", nrow(polygonrc))
poly<-polygonrc

p7<-ggplot(data=allcropNsuit, aes(x=month2, y=area_suit_ha, color=wetdry))+
  #ylim(0.2,0.8) +
  geom_line(aes(linetype=model), size=1.2)+
  theme_classic()+
  #theme(legend.position="none") +
  #labs(title="Nonrice Crop",x="Month by Water Year (Sept-Apr)", y = "Suitable Area (ha)")+ 
  labs(title="Nonrice Crop",x=" Sept   Oct   Nov   Dec   Jan   Feb   Mar   Apr)", y = "Suitable Area (ha)")+ 
  scale_color_manual(values=c('red', 'lightgray', 'blue')) +
  geom_polygon(data = polc, aes(y=y, x=x, color=wetdry), alpha = 0.3) +
  geom_polygon(data = poly, aes(y=y, x=x, color=wetdry), alpha = 0.3)
p7

# Multipanel figure function
##########################

multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

##########################

multiplot(p2, p7, p1, cols=3)
multiplot(p2, p3, p4, p5, p6, p7, cols=3)

