.libPaths("C:/R_packages")
library(rgdal)
library(raster)
library(data.table)
library(ggplot2)
library(SDMTools)
library(spatial)
library(GISTools)
library(dismo)
library(scales)
library(plyr)
library(splines2)
library(splines)

rasterOptions(tmpdir=paste("D:/temp/dir", Sys.Date(), sep=""))

summary_table<-as.data.frame(matrix(NA, 230, 7))
names(summary_table)<-c("date", "NS", "type", "model", "suit", "cells", "cells_NA")

#################################################################
# Load the summary areas file.  NORTH
#################################################################

wetlands<-raster("G:/CV_Seasonal_SemiPermenant_Wetlands/pubprivwetlnd")
rice<-raster("E:/Erin08302018/Attribution/Rice.tif")
isBecomes <- cbind(c(0), c(NA))
rice <- reclassify(rice, rcl=isBecomes)
plot(rice)

allcrops<-raster("E:/Erin08302018/Attribution/NonRiceCrops.tif")
allcrops <- reclassify(allcrops, rcl=isBecomes)
plot(allcrops)

basins2<-raster("F:/DUCKS/Basin_num.tif")
isBecomes <- cbind(c(NA, 6), c(0, 0))
basins2 <- reclassify(basins2, rcl=isBecomes)

sjbasin<-raster("G:/Ducks_final/sjoaq_basin")
basins2<-crop(basins2, extent(sjbasin))
isBecomes <- cbind(c(NA), c(0))

sjbasin <- reclassify(sjbasin, rcl=isBecomes)
basins<-basins2+sjbasin
isBecomes <- cbind(c(0), c(NA))

basins <- reclassify(basins, rcl=isBecomes)
plot(basins)

#Check extents
suitfile<-raster("G:/Ducks_final/FloodedCoverUSGS/Average_across_species/Average_weighted_FloodedCoverUSGS_across_spp_20150922to20150930_PA_pred05222020.tif") 
rice<-crop(rice, extent(suitfile))
allcrops<-crop(allcrops, extent(suitfile))

isBecomes<- cbind(c(11, 12, 21, 22), c(1, 1, 1, 1))
allwet<-reclassify(wetlands, rcl=isBecomes)
isBecomes<- cbind(c(11, 12, 21, 22), c(NA, 1, NA, 1))
pubwet<-reclassify(wetlands, rcl=isBecomes)
isBecomes<- cbind(c(11, 12, 21, 22), c(1, NA, 1, NA))
privwet<-reclassify(wetlands, rcl=isBecomes)
isBecomes<- cbind(c(11, 12, 21, 22), c(1, 1, NA, NA))
seaswet<-reclassify(wetlands, rcl=isBecomes)
isBecomes<- cbind(c(11, 12, 21, 22), c(NA, NA, 1, 1))
permwet<-reclassify(wetlands, rcl=isBecomes)
plot(allwet)

isBecomes<- cbind(c(4, 6, 7, 8, 9, 10), c(1, NA, 1, 1, 1, 1))
allbasins<-reclassify(basins, rcl=isBecomes)
isBecomes<- cbind(c(4, 6, 7, 8, 9, 10), c(NA, NA, NA, NA, 1, NA))
amer<-reclassify(basins, rcl=isBecomes)
isBecomes<- cbind(c(4, 6, 7, 8, 9, 10), c(NA, NA, 1, NA, NA, NA))
butte<-reclassify(basins, rcl=isBecomes)
isBecomes<- cbind(c(4, 6, 7, 8, 9, 10), c(NA, NA, NA, 1, NA, NA))
col<-reclassify(basins, rcl=isBecomes)
isBecomes<- cbind(c(4, 6, 7, 8, 9, 10), c(NA, NA, NA, NA, NA, 1))
sutter<-reclassify(basins, rcl=isBecomes)
isBecomes<- cbind(c(4, 6, 7, 8, 9, 10), c(1, NA, NA, NA, NA, NA))
yolo<-reclassify(basins, rcl=isBecomes)
plot(yolo)
#isBecomes<- cbind(c(4, 6, 7, 8, 9, 10), c(NA, 1, NA, NA, NA, NA))
#sj<-reclassify(basins, rcl=isBecomes)

#isBecomes <- cbind(c(4, 6, 7, 8, 9, 10), c(1, NA, 1, 1, 1, 1))
#basins <- reclassify(basins, rcl=isBecomes)
#basins2 <- raster::shift(basins, dy=5)

#################################
# Load the water files...
#################################

indir<-"G:/Ducks_final/FloodedCoverUSGS/Average_across_species"
indir2<-"G:/Ducks_final/FloodedCover/Average_across_species"
indir3<-"G:/Ducks_final/Longterm/Average_across_species"

#################################
# First Flooded Northern Areas
#################################

Wet<-c("20150922to20150930", "20141012to20141021", 
       "20161102to20161111", "20141224to20150103", 
       "20130907to20130916", "20131002to20131012", 
       "20131103to20131113", "20131221to20131231", 
       "20150321to20150330", "20140412to20140422",
       "20140106to20140116", "1-Feb2008to15Feb2008",
       "1-Jan2009to15Jan2009", "1-Feb2011to15Feb2011",
       "1-Mar2010to15Mar2010", "1-Apr2010to15Apr2010") 

moni<-c("Sep", "Oct", "Nov", "Dec", "Jan", "Feb", "Mar", "Apr")

tabrow<-1

# this loop checks that the file is there
for (ii in 1:length(Wet)) {
  
  suitfile_all<-raster(paste(indir, "/Average_weighted_FloodedCoverUSGS_across_spp_", Wet[ii], "_PA_pred05222020.tif", sep=""))  
  suitfile_all2<-raster(paste(indir2, "/Average_weighted_cover_across_spp_", Wet[ii], "_PA_pred05222020.tif", sep=""))
  if (ii<9) {
  suitfile_long2<-raster(paste(indir3, "/Average_across_spp_long_lowN", moni[ii] ,"_PA_pred09022020.tif", sep=""))
  }
  
  # Only comparing north and south separately...
#  suitfile<-suitfile_all*allbasins
#  suitfile2<-suitfile_all2*allbasins
  suitfile_long<-suitfile_long2*allbasins
  
  # Available Cells
#  xx<-freq(suitfile)
#  yy<-as.data.frame(xx)
#  cells01<-yy$count[which(yy$value==0)]+yy$count[which(yy$value==1)]
#  cellsNA<-yy$count[is.na(yy$value)]
  
  # COVER ONLY
  
#  ricesuit<-rice*suitfile2
#  averice<-cellStats(ricesuit, 'mean')
# summary_table[tabrow,]<-c(Wet[ii], "North", "rice", "CoverOnly", averice, cells01, cellsNA)
#  tabrow<-tabrow+1
  
#  cropsuit<-allcrops*suitfile2
#  avecrop<-cellStats(cropsuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "NonriceCrop", "CoverOnly", avecrop, cells01, cellsNA)
#  tabrow<-tabrow+1
  
#  wetsuit<-allwet*suitfile2
#  avewet<-cellStats(wetsuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "AllWetlands", "CoverOnly", avewet, cells01, cellsNA)
#  tabrow<-tabrow+1
  
#  pubsuit<-pubwet*suitfile2
#  avepub<-cellStats(pubsuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "PublicWetlands", "CoverOnly", avepub, cells01, cellsNA)
#  tabrow<-tabrow+1
  
#  privsuit<-privwet*suitfile2
#  avepriv<-cellStats(privsuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "PrivateWetlands", "CoverOnly", avepriv, cells01, cellsNA)
#  tabrow<-tabrow+1
  
#  seassuit<-seaswet*suitfile2
#  aveseas<-cellStats(seassuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "SeasonalWetlands", "CoverOnly", aveseas, cells01, cellsNA)
#  tabrow<-tabrow+1
  
#  permsuit<-permwet*suitfile2
#  aveperm<-cellStats(permsuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "PermanentWetlands", "CoverOnly", aveperm, cells01, cellsNA)
#  tabrow<-tabrow+1
  
#  allsuit<-allbasins*suitfile2
#  avesuit<-cellStats(allsuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "AllBasins", "CoverOnly", avesuit, cells01, cellsNA)
#  tabrow<-tabrow+1
  
#  amersuit<-amer*suitfile2
#  aveamersuit<-cellStats(amersuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "American", "CoverOnly", aveamersuit, cells01, cellsNA)
#  tabrow<-tabrow+1
  
#  butsuit<-butte*suitfile2
#  avebutsuit<-cellStats(butsuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "Butte", "CoverOnly", avebutsuit, cells01, cellsNA)
#  tabrow<-tabrow+1
  
#  colsuit<-col*suitfile2
#  avecolsuit<-cellStats(colsuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "Colusa", "CoverOnly", avecolsuit, cells01, cellsNA)
#  tabrow<-tabrow+1
  
#  sutsuit<-sutter*suitfile2
#  avesutsuit<-cellStats(sutsuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "Sutter", "CoverOnly", avesutsuit, cells01, cellsNA)
#  tabrow<-tabrow+1
  
#  yolosuit<-yolo*suitfile2
#  aveyolosuit<-cellStats(yolosuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "Yolo", "CoverOnly", aveyolosuit, cells01, cellsNA)
#  tabrow<-tabrow+1
  
  #plot(suitrice, xlim=c(550000, 660000), ylim=c(4200000, 4420000), main="Flooded rice")
  #plot(wet, xlim=c(550000, 660000), ylim=c(4200000, 4420000), main="Flooded wetlands")
  #plot(water, xlim=c(550000, 660000), ylim=c(4200000, 4420000), main="All Flooded")
  #plot(allcrops, xlim=c(550000, 660000), ylim=c(4200000, 4420000), main="Non-rice, non-orchard crops")
  
  
  # COVER YIELD
  
 # ricesuit<-rice*suitfile
#  averice<-cellStats(ricesuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "rice", "CoverYield", averice, cells01, cellsNA)
 # tabrow<-tabrow+1
  
 # cropsuit<-allcrops*suitfile
#  avecrop<-cellStats(cropsuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "NonriceCrop", "CoverYield", avecrop, cells01, cellsNA)
#  tabrow<-tabrow+1
  
#  wetsuit<-allwet*suitfile
#  avewet<-cellStats(wetsuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "AllWetlands", "CoverYield", avewet, cells01, cellsNA)
 # tabrow<-tabrow+1
  
#  pubsuit<-pubwet*suitfile
 # avepub<-cellStats(pubsuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "PublicWetlands", "CoverYield", avepub, cells01, cellsNA)
 # tabrow<-tabrow+1
  
#  privsuit<-privwet*suitfile
#  avepriv<-cellStats(privsuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "PrivateWetlands", "CoverYield", avepriv, cells01, cellsNA)
 # tabrow<-tabrow+1
  
#  seassuit<-seaswet*suitfile
#  aveseas<-cellStats(seassuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "SeasonalWetlands", "CoverYield", aveseas, cells01, cellsNA)
 # tabrow<-tabrow+1
  
  #permsuit<-permwet*suitfile
  #aveperm<-cellStats(permsuit, 'mean')
  #summary_table[tabrow,]<-c(Wet[ii], "North", "PermanentWetlands", "CoverYield", aveperm, cells01, cellsNA)
  #tabrow<-tabrow+1
  
  #allsuit<-allbasins*suitfile
 # avesuit<-cellStats(allsuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "AllBasins", "CoverYield", avesuit, cells01, cellsNA)
 # tabrow<-tabrow+1
  
#  amersuit<-amer*suitfile
 # aveamersuit<-cellStats(amersuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "American", "CoverYield", aveamersuit, cells01, cellsNA)
#  tabrow<-tabrow+1
  
 # butsuit<-butte*suitfile
#  avebutsuit<-cellStats(butsuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "Butte", "CoverYield", avebutsuit, cells01, cellsNA)
 # tabrow<-tabrow+1
  
#  colsuit<-col*suitfile
 # avecolsuit<-cellStats(colsuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "Colusa", "CoverYield", avecolsuit, cells01, cellsNA)
 # tabrow<-tabrow+1
  
#  sutsuit<-sutter*suitfile
 # avesutsuit<-cellStats(sutsuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "Sutter", "CoverYield", avesutsuit, cells01, cellsNA)
#  tabrow<-tabrow+1
  
#  yolosuit<-yolo*suitfile
#  aveyolosuit<-cellStats(yolosuit, 'mean')
#  summary_table[tabrow,]<-c(Wet[ii], "North", "Yolo", "CoverYield", aveyolosuit, cells01, cellsNA)
 # tabrow<-tabrow+1
  
  
  # LONG Available Cells
  xx<-freq(suitfile_long)
  yy<-as.data.frame(xx)
  cells01<-yy$count[which(yy$value==0)]+yy$count[which(yy$value==1)]
  cellsNA<-yy$count[is.na(yy$value)]
  
  # LONG
  if (ii<9) {
  
  ricesuit<-rice*suitfile_long
  averice<-cellStats(ricesuit, 'mean')
  summary_table[tabrow,]<-c(moni[ii], "North", "rice", "long", averice, cells01, cellsNA)
  tabrow<-tabrow+1
  
  cropsuit<-allcrops*suitfile_long
  avecrop<-cellStats(cropsuit, 'mean')
  summary_table[tabrow,]<-c(moni[ii], "North", "NonriceCrop", "long", avecrop, cells01, cellsNA)
  tabrow<-tabrow+1
  
  wetsuit<-allwet*suitfile_long
  avewet<-cellStats(wetsuit, 'mean')
  summary_table[tabrow,]<-c(moni[ii], "North", "AllWetlands", "long", avewet, cells01, cellsNA)
  tabrow<-tabrow+1
  
  pubsuit<-pubwet*suitfile_long
  avepub<-cellStats(pubsuit, 'mean')
  summary_table[tabrow,]<-c(moni[ii], "North", "PublicWetlands", "long", avepub, cells01, cellsNA)
  tabrow<-tabrow+1
  
  privsuit<-privwet*suitfile_long
  avepriv<-cellStats(privsuit, 'mean')
  summary_table[tabrow,]<-c(moni[ii], "North", "PrivateWetlands", "long", avepriv, cells01, cellsNA)
  tabrow<-tabrow+1
  
  seassuit<-seaswet*suitfile_long
  aveseas<-cellStats(seassuit, 'mean')
  summary_table[tabrow,]<-c(moni[ii], "North", "SeasonalWetlands", "long", aveseas, cells01, cellsNA)
  tabrow<-tabrow+1
  
  permsuit<-permwet*suitfile_long
  aveperm<-cellStats(permsuit, 'mean')
  summary_table[tabrow,]<-c(moni[ii], "North", "PermanentWetlands", "long", aveperm, cells01, cellsNA)
  tabrow<-tabrow+1
  
  allsuit<-allbasins*suitfile_long
  avesuit<-cellStats(allsuit, 'mean')
  summary_table[tabrow,]<-c(moni[ii], "North", "AllBasins", "long", avesuit, cells01, cellsNA)
  tabrow<-tabrow+1
  
  amersuit<-amer*suitfile_long
  aveamersuit<-cellStats(amersuit, 'mean')
  summary_table[tabrow,]<-c(moni[ii], "North", "American", "long", aveamersuit, cells01, cellsNA)
  tabrow<-tabrow+1
  
  butsuit<-butte*suitfile_long
  avebutsuit<-cellStats(butsuit, 'mean')
  summary_table[tabrow,]<-c(moni[ii], "North", "Butte", "long", avebutsuit, cells01, cellsNA)
  tabrow<-tabrow+1
  
  colsuit<-col*suitfile_long
  avecolsuit<-cellStats(colsuit, 'mean')
  summary_table[tabrow,]<-c(moni[ii], "North", "Colusa", "long", avecolsuit, cells01, cellsNA)
  tabrow<-tabrow+1
  
  sutsuit<-sutter*suitfile_long
  avesutsuit<-cellStats(sutsuit, 'mean')
  summary_table[tabrow,]<-c(moni[ii], "North", "Sutter", "long", avesutsuit, cells01, cellsNA)
  tabrow<-tabrow+1
  
  yolosuit<-yolo*suitfile_long
  aveyolosuit<-cellStats(yolosuit, 'mean')
  summary_table[tabrow,]<-c(moni[ii], "North", "Yolo", "long", aveyolosuit, cells01, cellsNA)
  tabrow<-tabrow+1
  }
  
 # sjsuit<-sj*suitfile
 # amersuit<-cellStats(amersuit, 'mean')
 # summary_table[tabrow,]<-c(Wet[ii], "North", "American", "CoverYield", amersuit, cells01, cellsNA)
  

  write.csv(summary_table, "G:/Ducks_Final/SuitabilityByCoverLongNorth09022020.csv")

}


#################################################################
# Load the summary areas file.  SOUTH
#################################################################


wetlands<-raster("G:/CV_Seasonal_SemiPermenant_Wetlands/pubprivwetlnd")
rice<-raster("E:/Erin08302018/Attribution/Rice.tif")
isBecomes <- cbind(c(0), c(NA))
rice <- reclassify(rice, rcl=isBecomes)

allcrops<-raster("E:/Erin08302018/Attribution/NonRiceCrops.tif")
allcrops <- reclassify(allcrops, rcl=isBecomes)

sjbasin<-raster("G:/Ducks_final/sjoaq_basin")
isBecomes <- cbind(c(6), c(1))
sj <- reclassify(sjbasin, rcl=isBecomes)
plot(sj)

#Check extents
suitfile<-raster("G:/Ducks_final/FloodedCoverUSGS/Average_across_species/Average_weighted_FloodedCoverUSGS_across_spp_20150922to20150930_PA_pred05222020.tif") 
rice<-crop(rice, extent(suitfile))
allcrops<-crop(allcrops, extent(suitfile))

isBecomes<- cbind(c(11, 12, 21, 22), c(1, 1, 1, 1))
allwet<-reclassify(wetlands, rcl=isBecomes)
isBecomes<- cbind(c(11, 12, 21, 22), c(NA, 1, NA, 1))
pubwet<-reclassify(wetlands, rcl=isBecomes)
isBecomes<- cbind(c(11, 12, 21, 22), c(1, NA, 1, NA))
privwet<-reclassify(wetlands, rcl=isBecomes)
isBecomes<- cbind(c(11, 12, 21, 22), c(1, 1, NA, NA))
seaswet<-reclassify(wetlands, rcl=isBecomes)
isBecomes<- cbind(c(11, 12, 21, 22), c(NA, NA, 1, 1))
permwet<-reclassify(wetlands, rcl=isBecomes)

#isBecomes<- cbind(c(4, 6, 7, 8, 9, 10), c(NA, 1, NA, NA, NA, NA))
#sj<-reclassify(basins, rcl=isBecomes)


#################################
# Load the water files...
#################################

indir<-"G:/Ducks_final/FloodedCoverUSGS/Average_across_species"
indir2<-"G:/Ducks_final/FloodedCover/Average_across_species"
indir3<-"G:/Ducks_final/Longterm/Average_across_species"

#################################
# Flooded Southern Areas
#################################


Wet<-c("20130907to20130916",
         "20141012to20141021",
         "2010-11-01to2010-11-15",
         "20131221to20131231",
         "2010-1-16to2010-1-31",
         "2015-2-26to2015-3-06",
         "2014-3-02to2014-3-11",
         "2014-4-19to2014-4-28",
         "2011-9-01to2011-9-15",
         "20131002to20131012",
         "2013-11-26to2013-12-05",
         "2016-12-20to2016-12-29",
         "2014-1-13to2014-1-22",
         "2016-2-20to2016-2-29",
         "2016-3-07to2016-3-16",
         "2016-4-01to2016-4-11")

summary_table_south<-as.data.frame(matrix(NA, 230, 7))
names(summary_table_south)<-c("date", "NS", "type", "model", "suit", "cells", "cells_NA")

moni<-c("Sep", "Oct", "Nov", "Dec", "Jan", "Feb", "Mar", "Apr")

tabrow<-1


for (ii in 1:length(Wet)) {
#  if (Wet[ii]=="2016-12-20to2016-12-29") {
#    suitfile_all<-raster(paste(indir, "/Average_weighted_FloodedCoverUSGS_across_spp_", Wet[ii], "_PA_tmax2015_pred05222020.tif", sep=""))
#    suitfile_all2<-raster(paste(indir2, "/Average_weighted_cover_across_spp_", Wet[ii], "_PA_tmax2015_pred05222020.tif", sep=""))
#  } else {
#    suitfile_all<-raster(paste(indir, "/Average_weighted_FloodedCoverUSGS_across_spp_", Wet[ii], "_PA_pred05222020.tif", sep=""))
#    suitfile_all2<-raster(paste(indir2, "/Average_weighted_cover_across_spp_", Wet[ii], "_PA_pred05222020.tif", sep=""))
#  }
  if (ii<9) {
    suitfile_long2<-raster(paste(indir3, "/Average_across_spp_long_lowN", moni[ii] ,"_PA_pred09022020.tif", sep=""))
  }
  # Only comparing north and south separately...
  #suitfile<-suitfile_all*sj
  #suitfile2<-suitfile_all2*sj
  suitfile_long<-suitfile_long2*sj
  
  
  # Available Cells
  #xx<-freq(suitfile2)
  #yy<-as.data.frame(xx)
  #cells01<-yy$count[which(yy$value==0)]+yy$count[which(yy$value==1)]
  #cellsNA<-yy$count[is.na(yy$value)]
  
  # COVER ONLY
  #ricesuit<-rice*suitfile2
  #averice<-cellStats(ricesuit, 'mean')
  #summary_table_south[tabrow,]<-c(Wet[ii], "South", "rice", "CoverOnly", averice, cells01, cellsNA)
  #tabrow<-tabrow+1
  
  #cropsuit<-allcrops*suitfile2
  #avecrop<-cellStats(cropsuit, 'mean')
  #summary_table_south[tabrow,]<-c(Wet[ii], "South", "NonriceCrop", "CoverOnly", avecrop, cells01, cellsNA)
  #tabrow<-tabrow+1
  
  #wetsuit<-allwet*suitfile2
  #avewet<-cellStats(wetsuit, 'mean')
  #summary_table_south[tabrow,]<-c(Wet[ii], "South", "AllWetlands", "CoverOnly", avewet, cells01, cellsNA)
  #tabrow<-tabrow+1
  
  # pubsuit<-pubwet*suitfile2
  #avepub<-cellStats(pubsuit, 'mean')
  #summary_table_south[tabrow,]<-c(Wet[ii], "South", "PublicWetlands", "CoverOnly", avepub, cells01, cellsNA)
  #tabrow<-tabrow+1
  
  #privsuit<-privwet*suitfile2
  #avepriv<-cellStats(privsuit, 'mean')
  #summary_table_south[tabrow,]<-c(Wet[ii], "South", "PrivateWetlands", "CoverOnly", avepriv, cells01, cellsNA)
  #tabrow<-tabrow+1
  
  #seassuit<-seaswet*suitfile2
  #aveseas<-cellStats(seassuit, 'mean')
  #summary_table_south[tabrow,]<-c(Wet[ii], "South", "SeasonalWetlands", "CoverOnly", aveseas, cells01, cellsNA)
  #tabrow<-tabrow+1
  
  #permsuit<-permwet*suitfile2
  #aveperm<-cellStats(permsuit, 'mean')
  #summary_table_south[tabrow,]<-c(Wet[ii], "South", "PermanentWetlands", "CoverOnly", aveperm, cells01, cellsNA)
  #tabrow<-tabrow+1
  
  #allsuit<-sj*suitfile2
  #avesuit<-cellStats(allsuit, 'mean')
  #summary_table_south[tabrow,]<-c(Wet[ii], "South", "SanJoaquin", "CoverOnly", avesuit, cells01, cellsNA)
  #tabrow<-tabrow+1
  
  #plot(suitrice, xlim=c(550000, 660000), ylim=c(4200000, 4420000), main="Flooded rice")
  #plot(wet, xlim=c(550000, 660000), ylim=c(4200000, 4420000), main="Flooded wetlands")
  #plot(water, xlim=c(550000, 660000), ylim=c(4200000, 4420000), main="All Flooded")
  #plot(allcrops, xlim=c(550000, 660000), ylim=c(4200000, 4420000), main="Non-rice, non-orchard crops")
 
   # Available Cells
  # xx<-freq(suitfile)
  #  yy<-as.data.frame(xx)
  # cells01<-yy$count[which(yy$value==0)]+yy$count[which(yy$value==1)]
  #  cellsNA<-yy$count[is.na(yy$value)]
  
  # COVER YIELD
  # ricesuit<-rice*suitfile
  #  averice<-cellStats(ricesuit, 'mean')
  #  summary_table_south[tabrow,]<-c(Wet[ii], "South", "rice", "CoverYield", averice, cells01, cellsNA)
  #  tabrow<-tabrow+1
  
  #  cropsuit<-allcrops*suitfile
  #  avecrop<-cellStats(cropsuit, 'mean')
  #  summary_table_south[tabrow,]<-c(Wet[ii], "South", "NonriceCrop", "CoverYield", avecrop, cells01, cellsNA)
  #  tabrow<-tabrow+1
  
  #  wetsuit<-allwet*suitfile
  #  avewet<-cellStats(wetsuit, 'mean')
  #  summary_table_south[tabrow,]<-c(Wet[ii], "South", "AllWetlands", "CoverYield", avewet, cells01, cellsNA)
  #  tabrow<-tabrow+1
  
  #  pubsuit<-pubwet*suitfile
  #  avepub<-cellStats(pubsuit, 'mean')
  #  summary_table_south[tabrow,]<-c(Wet[ii], "South", "PublicWetlands", "CoverYield", avepub, cells01, cellsNA)
  #  tabrow<-tabrow+1
  
  #  privsuit<-privwet*suitfile
  #  avepriv<-cellStats(privsuit, 'mean')
  #  summary_table_south[tabrow,]<-c(Wet[ii], "South", "PrivateWetlands", "CoverYield", avepriv, cells01, cellsNA)
  #  tabrow<-tabrow+1
  
  #  seassuit<-seaswet*suitfile
  #  aveseas<-cellStats(seassuit, 'mean')
  #  summary_table_south[tabrow,]<-c(Wet[ii], "South", "SeasonalWetlands", "CoverYield", aveseas, cells01, cellsNA)
  #  tabrow<-tabrow+1
  
  #  permsuit<-permwet*suitfile
  #  aveperm<-cellStats(permsuit, 'mean')
  #  summary_table_south[tabrow,]<-c(Wet[ii], "South", "PermanentWetlands", "CoverYield", aveperm, cells01, cellsNA)
  #  tabrow<-tabrow+1
  
  #  allsuit<-sj*suitfile
  #  avesuit<-cellStats(allsuit, 'mean')
  #  summary_table_south[tabrow,]<-c(Wet[ii], "South", "SanJoaquin", "CoverYield", avesuit, cells01, cellsNA)
  #  tabrow<-tabrow+1
  # LONG Available Cells
  
  xx<-freq(suitfile_long)
  yy<-as.data.frame(xx)
  cells01<-yy$count[which(yy$value==0)]+yy$count[which(yy$value==1)]
  cellsNA<-yy$count[is.na(yy$value)]
  
  # LONG
  ricesuit<-rice*suitfile_long
  averice<-cellStats(ricesuit, 'mean')
  summary_table_south[tabrow,]<-c(moni[ii], "South", "rice", "Long", averice, cells01, cellsNA)
  tabrow<-tabrow+1
  
  cropsuit<-allcrops*suitfile_long
  avecrop<-cellStats(cropsuit, 'mean')
  summary_table_south[tabrow,]<-c(moni[ii], "South", "NonriceCrop", "Long", avecrop, cells01, cellsNA)
  tabrow<-tabrow+1
  
  wetsuit<-allwet*suitfile_long
  avewet<-cellStats(wetsuit, 'mean')
  summary_table_south[tabrow,]<-c(moni[ii], "South", "AllWetlands", "Long", avewet, cells01, cellsNA)
  tabrow<-tabrow+1
  
  pubsuit<-pubwet*suitfile_long
  avepub<-cellStats(pubsuit, 'mean')
  summary_table_south[tabrow,]<-c(moni[ii], "South", "PublicWetlands", "Long", avepub, cells01, cellsNA)
  tabrow<-tabrow+1
  
  privsuit<-privwet*suitfile_long
  avepriv<-cellStats(privsuit, 'mean')
  summary_table_south[tabrow,]<-c(moni[ii], "South", "PrivateWetlands", "Long", avepriv, cells01, cellsNA)
  tabrow<-tabrow+1
  
  seassuit<-seaswet*suitfile_long
  aveseas<-cellStats(seassuit, 'mean')
  summary_table_south[tabrow,]<-c(moni[ii], "South", "SeasonalWetlands", "Long", aveseas, cells01, cellsNA)
  tabrow<-tabrow+1
  
  permsuit<-permwet*suitfile_long
  aveperm<-cellStats(permsuit, 'mean')
  summary_table_south[tabrow,]<-c(moni[ii], "South", "PermanentWetlands", "Long", aveperm, cells01, cellsNA)
  tabrow<-tabrow+1
  
  allsuit<-sj*suitfile_long
  avesuit<-cellStats(allsuit, 'mean')
  summary_table_south[tabrow,]<-c(moni[ii], "South", "SanJoaquin", "Long", avesuit, cells01, cellsNA)
  tabrow<-tabrow+1
  
  write.csv(summary_table_south, "G:/Ducks_Final/SuitabilityByCoverSouth09082020.csv")
}




